@@ -6,7 +6,7 @@ from gammapy.astro.source import Pulsar
 
 t = Quantity(np.logspace(0, 6, 100), "yr")
 
-pulsar = Pulsar(P_0=Quantity(0.01, "s"), logB=12)
+pulsar = Pulsar(P_0=Quantity(0.01, "s"), B="1e12 G")
 
 plt.plot(t.value, 1 / pulsar.period(t).cgs.value)
 plt.xlabel("time [years]")
