@@ -1,19 +1,17 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Source catalog and object base classes."""
-from __future__ import absolute_import, division, print_function, unicode_literals
 from collections import OrderedDict
 import copy
 import numpy as np
+from astropy.coordinates import SkyCoord
 from astropy.utils import lazyproperty
-from ..extern import six
 from ..utils.array import _is_int
-from ..utils.table import table_row_to_dict
-from .utils import skycoord_from_table
+from ..utils.table import table_row_to_dict, table_from_row_data
 
 __all__ = ["SourceCatalog", "SourceCatalogObject"]
 
 
-class SourceCatalogObject(object):
+class SourceCatalogObject:
     """Source catalog object.
 
     This class can be used directly, but it's mostly used as a
@@ -49,8 +47,9 @@ class SourceCatalogObject(object):
 
     @property
     def _data_python_dict(self):
-        """Convert ``data`` into a Python dict that only contains
-        Python data types, i.e. is readily JSON or YAML serialisable.
+        """Convert ``data`` to a Python dict with Python types.
+
+        The dict is readily JSON or YAML serializable.
         Quantity unit information is stripped.
 
         This is mainly used at the moment to pass the data to
@@ -73,10 +72,11 @@ class SourceCatalogObject(object):
     @property
     def position(self):
         """Source position (`~astropy.coordinates.SkyCoord`)."""
-        return skycoord_from_table(self.data)
+        table = table_from_row_data([self.data])
+        return _skycoord_from_table(table)[0]
 
 
-class SourceCatalog(object):
+class SourceCatalog:
     """Generic source catalog.
 
     This class can be used directly, but it's mostly used as a
@@ -181,7 +181,7 @@ class SourceCatalog(object):
         At the moment this can raise KeyError, IndexError and ValueError
         for invalid keys. Should we always raise KeyError to simplify this?
         """
-        if isinstance(key, six.string_types):
+        if isinstance(key, str):
             index = self.row_index(key)
         elif _is_int(key):
             index = key
@@ -226,8 +226,9 @@ class SourceCatalog(object):
 
     @property
     def _data_python_list(self):
-        """Convert catalog into a Python list that only contains
-        Python data types, i.e. is readily JSON or YAML serialisable.
+        """Convert catalog to a Python list with Python types.
+
+        The list is readily JSON or YAML serializable.
         Quantity unit information is stripped.
 
         This is mainly used at the moment to pass the data to
@@ -238,8 +239,32 @@ class SourceCatalog(object):
     @property
     def positions(self):
         """Source positions (`~astropy.coordinates.SkyCoord`)."""
-        return skycoord_from_table(self.table)
+        return _skycoord_from_table(self.table)
 
     def copy(self):
         """Copy catalog"""
         return copy.deepcopy(self)
+
+
+def _skycoord_from_table(table):
+    try:
+        keys = table.colnames
+    except AttributeError:
+        keys = list(table.keys())
+
+    if {"RAJ2000", "DEJ2000"}.issubset(keys):
+        lon, lat, frame = "RAJ2000", "DEJ2000", "icrs"
+    elif {"RA", "DEC"}.issubset(keys):
+        lon, lat, frame = "RA", "DEC", "icrs"
+    elif {"ra", "dec"}.issubset(keys):
+        lon, lat, frame = "ra", "dec", "icrs"
+    elif {"GLON", "GLAT"}.issubset(keys):
+        lon, lat, frame = "GLON", "GLAT", "galactic"
+    elif {"glon", "glat"}.issubset(keys):
+        lon, lat, frame = "glon", "glat", "galactic"
+    else:
+        raise KeyError("No column GLON / GLAT or RA / DEC or RAJ2000 / DEJ2000 found.")
+
+    unit = table[lon].unit.to_string() if table[lon].unit else "deg"
+
+    return SkyCoord(table[lon], table[lat], unit=unit, frame=frame)
