@@ -1,13 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Fermi catalog and source classes."""
-from __future__ import absolute_import, division, print_function, unicode_literals
 import warnings
 import numpy as np
 import astropy.units as u
 from astropy.table import Table, Column
 from astropy.time import Time
 from ..utils.scripts import make_path
-from ..utils.energy import EnergyBounds
 from ..utils.table import table_standardise_units_inplace
 from ..maps import Map
 from ..spectrum import FluxPoints
@@ -15,6 +13,7 @@ from ..spectrum.models import (
     PowerLaw,
     PowerLaw2,
     ExponentialCutoffPowerLaw3FGL,
+    PLSuperExpCutoff4FGL,
     PLSuperExpCutoff3FGL,
     LogParabola,
 )
@@ -24,10 +23,12 @@ from ..time import LightCurve
 from .core import SourceCatalog, SourceCatalogObject
 
 __all__ = [
+    "SourceCatalogObject4FGL",
     "SourceCatalogObject3FGL",
     "SourceCatalogObject1FHL",
     "SourceCatalogObject2FHL",
     "SourceCatalogObject3FHL",
+    "SourceCatalog4FGL",
     "SourceCatalog3FGL",
     "SourceCatalog1FHL",
     "SourceCatalog2FHL",
@@ -43,13 +44,60 @@ def compute_flux_points_ul(quantity, quantity_errp):
     return 2 * quantity_errp + quantity
 
 
+class SourceCatalogObject4FGL(SourceCatalogObject):
+    """One source from the Fermi-LAT 4FGL catalog.
+
+    Catalog is represented by `~gammapy.catalog.SourceCatalog4FGL`.
+    """
+
+    @property
+    def spectral_model(self):
+        """Best fit spectral model (`~gammapy.spectrum.models.SpectralModel`)."""
+        spec_type = self.data["SpectrumType"].strip()
+
+        pars, errs = {}, {}
+        pars["reference"] = self.data["Pivot_Energy"]
+
+        if spec_type == "PowerLaw":
+            pars["amplitude"] = self.data["PL_Flux_Density"]
+            pars["index"] = self.data["PL_Index"]
+            errs["amplitude"] = self.data["Unc_PL_Flux_Density"]
+            errs["index"] = self.data["Unc_PL_Index"]
+            model = PowerLaw(**pars)
+        elif spec_type == "LogParabola":
+            pars["amplitude"] = self.data["LP_Flux_Density"]
+            pars["alpha"] = self.data["LP_Index"]
+            pars["beta"] = self.data["LP_beta"]
+            errs["amplitude"] = self.data["Unc_LP_Flux_Density"]
+            errs["alpha"] = self.data["Unc_LP_Index"]
+            errs["beta"] = self.data["Unc_LP_beta"]
+            model = LogParabola(**pars)
+        elif spec_type == "PLSuperExpCutoff":
+            pars["amplitude"] = self.data["PLEC_Flux_Density"]
+            pars["index_1"] = self.data["PLEC_Index"]
+            pars["index_2"] = self.data["PLEC_Exp_Index"]
+            pars["expfactor"] = self.data["PLEC_Expfactor"] / u.MeV ** pars["index_2"]
+            errs["amplitude"] = self.data["Unc_PLEC_Flux_Density"]
+            errs["index_1"] = self.data["Unc_PLEC_Index"]
+            errs["index_2"] = np.nan_to_num(self.data["Unc_PLEC_Exp_Index"])
+            errs["expfactor"] = (
+                self.data["Unc_PLEC_Expfactor"] / u.MeV ** pars["index_2"]
+            )
+            model = PLSuperExpCutoff4FGL(**pars)
+        else:
+            raise ValueError("Invalid spec_type: {!r}".format(spec_type))
+
+        model.parameters.set_parameter_errors(errs)
+        return model
+
+
 class SourceCatalogObject3FGL(SourceCatalogObject):
     """One source from the Fermi-LAT 3FGL catalog.
 
     Catalog is represented by `~gammapy.catalog.SourceCatalog3FGL`.
     """
 
-    _ebounds = EnergyBounds([100, 300, 1000, 3000, 10000, 100000], "MeV")
+    _ebounds = u.Quantity([100, 300, 1000, 3000, 10000, 100000], "MeV")
     _ebounds_suffix = ["100_300", "300_1000", "1000_3000", "3000_10000", "10000_100000"]
     energy_range = u.Quantity([100, 100000], "MeV")
     """Energy range of the catalog.
@@ -364,7 +412,7 @@ class SourceCatalogObject3FGL(SourceCatalogObject):
         """Source sky model (`~gammapy.cube.models.SkyModel`)."""
         spatial_model = self.spatial_model
         spectral_model = self.spectral_model
-        return SkyModel(spatial_model, spectral_model)
+        return SkyModel(spatial_model, spectral_model, name=self.name)
 
     @property
     def is_pointlike(self):
@@ -375,10 +423,9 @@ class SourceCatalogObject3FGL(SourceCatalogObject):
         """Flux points (`~gammapy.spectrum.FluxPoints`)."""
         table = Table()
         table.meta["SED_TYPE"] = "flux"
-        e_ref = self._ebounds.log_centers
-        table["e_ref"] = e_ref
-        table["e_min"] = self._ebounds.lower_bounds
-        table["e_max"] = self._ebounds.upper_bounds
+
+        table["e_min"] = self._ebounds[:-1]
+        table["e_max"] = self._ebounds[1:]
 
         flux = self._get_flux_values("Flux")
         flux_err = self._get_flux_values("Unc_Flux")
@@ -418,7 +465,6 @@ class SourceCatalogObject3FGL(SourceCatalogObject):
 
         Examples
         --------
-
         >>> from gammapy.catalog import source_catalogs
         >>> source = source_catalogs['3fgl']['3FGL J0349.9-2102']
         >>> lc = source.lightcurve
@@ -464,7 +510,7 @@ class SourceCatalogObject1FHL(SourceCatalogObject):
     Catalog is represented by `~gammapy.catalog.SourceCatalog1FHL`.
     """
 
-    _ebounds = EnergyBounds([10, 30, 100, 500], "GeV")
+    _ebounds = u.Quantity([10, 30, 100, 500], "GeV")
     _ebounds_suffix = ["10_30", "30_100", "100_500"]
     energy_range = u.Quantity([0.01, 0.5], "TeV")
     """Energy range of the Fermi 1FHL source catalog"""
@@ -501,8 +547,8 @@ class SourceCatalogObject1FHL(SourceCatalogObject):
         """Integral flux points (`~gammapy.spectrum.FluxPoints`)."""
         table = Table()
         table.meta["SED_TYPE"] = "flux"
-        table["e_min"] = self._ebounds.lower_bounds
-        table["e_max"] = self._ebounds.upper_bounds
+        table["e_min"] = self._ebounds[:-1]
+        table["e_max"] = self._ebounds[1:]
         table["flux"] = self._get_flux_values("Flux")
         flux_err = self._get_flux_values("Unc_Flux")
         table["flux_errn"] = np.abs(flux_err[:, 0])
@@ -536,7 +582,7 @@ class SourceCatalogObject2FHL(SourceCatalogObject):
     Catalog is represented by `~gammapy.catalog.SourceCatalog2FHL`.
     """
 
-    _ebounds = EnergyBounds([50, 171, 585, 2000], "GeV")
+    _ebounds = u.Quantity([50, 171, 585, 2000], "GeV")
     _ebounds_suffix = ["50_171", "171_585", "585_2000"]
     energy_range = u.Quantity([0.05, 2], "TeV")
     """Energy range of the Fermi 2FHL source catalog"""
@@ -573,8 +619,8 @@ class SourceCatalogObject2FHL(SourceCatalogObject):
         """Integral flux points (`~gammapy.spectrum.FluxPoints`)."""
         table = Table()
         table.meta["SED_TYPE"] = "flux"
-        table["e_min"] = self._ebounds.lower_bounds
-        table["e_max"] = self._ebounds.upper_bounds
+        table["e_min"] = self._ebounds[:-1]
+        table["e_max"] = self._ebounds[1:]
         table["flux"] = self._get_flux_values("Flux")
         flux_err = self._get_flux_values("Unc_Flux")
         table["flux_errn"] = np.abs(flux_err[:, 0])
@@ -613,7 +659,7 @@ class SourceCatalogObject3FHL(SourceCatalogObject):
     energy_range = u.Quantity([0.01, 2], "TeV")
     """Energy range of the Fermi 1FHL source catalog"""
 
-    _ebounds = EnergyBounds([10, 20, 50, 150, 500, 2000], "GeV")
+    _ebounds = u.Quantity([10, 20, 50, 150, 500, 2000], "GeV")
 
     def __str__(self):
         return self.info()
@@ -834,10 +880,8 @@ class SourceCatalogObject3FHL(SourceCatalogObject):
         """Flux points (`~gammapy.spectrum.FluxPoints`)."""
         table = Table()
         table.meta["SED_TYPE"] = "flux"
-        e_ref = self._ebounds.log_centers
-        table["e_ref"] = e_ref
-        table["e_min"] = self._ebounds.lower_bounds
-        table["e_max"] = self._ebounds.upper_bounds
+        table["e_min"] = self._ebounds[:-1]
+        table["e_max"] = self._ebounds[1:]
 
         flux = self.data["Flux_Band"]
         flux_err = self.data["Unc_Flux_Band"]
@@ -905,7 +949,7 @@ class SourceCatalogObject3FHL(SourceCatalogObject):
         """Source sky model (`~gammapy.cube.models.SkyModel`)."""
         spatial_model = self.spatial_model
         spectral_model = self.spectral_model
-        return SkyModel(spatial_model, spectral_model)
+        return SkyModel(spatial_model, spectral_model, name=self.name)
 
     @property
     def is_pointlike(self):
@@ -975,7 +1019,7 @@ class SourceCatalog3FGL(SourceCatalog):
             "ASSOC1",
             "ASSOC2",
         )
-        super(SourceCatalog3FGL, self).__init__(
+        super().__init__(
             table=table,
             source_name_key=source_name_key,
             source_name_alias=source_name_alias,
@@ -989,7 +1033,7 @@ class SourceCatalog3FGL(SourceCatalog):
 
         The classes are described in Table 3 of the 3FGL paper:
 
-        http://adsabs.harvard.edu/abs/2015arXiv150102003T
+        https://ui.adsabs.harvard.edu/abs/2015ApJS..218...23A
 
         Parameters
         ----------
@@ -1020,7 +1064,7 @@ class SourceCatalog3FGL(SourceCatalog):
         elif source_class == "all":
             category = set(cats["extra-galactic"] + cats["galactic"])
         elif source_class in np.unique(source_class_info):
-            category = set([source_class])
+            category = {source_class}
         else:
             raise ValueError("Invalid source_class: {!r}".format(source_class))
 
@@ -1048,10 +1092,51 @@ class SourceCatalog3FGL(SourceCatalog):
         return catalog
 
 
+class SourceCatalog4FGL(SourceCatalog):
+    """Fermi-LAT 4FGL source catalog.
+
+    References:
+
+    - https://arxiv.org/abs/1902.10045
+    - https://fermi.gsfc.nasa.gov/ssc/data/access/lat/8yr_catalog/
+
+    One source is represented by `~gammapy.catalog.SourceCatalogObject4FGL`.
+    """
+
+    name = "4fgl"
+    description = "LAT 8-year point source catalog"
+    source_object_class = SourceCatalogObject4FGL
+
+    def __init__(self, filename="$GAMMAPY_DATA/catalogs/fermi/gll_psc_v19.fit.gz"):
+        filename = str(make_path(filename))
+        table = Table.read(filename, hdu="LAT_Point_Source_Catalog")
+        table_standardise_units_inplace(table)
+
+        source_name_key = "Source_Name"
+        source_name_alias = (
+            "Extended_Source_Name",
+            "ASSOC_FGL",
+            "ASSOC_FHL",
+            "ASSOC_GAM1",
+            "ASSOC_GAM2",
+            "ASSOC_GAM3",
+            "ASSOC_TEV",
+            "ASSOC1",
+            "ASSOC2",
+        )
+        super().__init__(
+            table=table,
+            source_name_key=source_name_key,
+            source_name_alias=source_name_alias,
+        )
+
+        self.extended_sources_table = Table.read(filename, hdu="ExtendedSources")
+
+
 class SourceCatalog1FHL(SourceCatalog):
     """Fermi-LAT 1FHL source catalog.
 
-    Reference: http://adsabs.harvard.edu/abs/2013ApJS..209...34A
+    Reference: https://ui.adsabs.harvard.edu/abs/2013ApJS..209...34A
 
     One source is represented by `~gammapy.catalog.SourceCatalogObject1FHL`.
     """
@@ -1071,7 +1156,7 @@ class SourceCatalog1FHL(SourceCatalog):
 
         source_name_key = "Source_Name"
         source_name_alias = ("ASSOC1", "ASSOC2", "ASSOC_TEV", "ASSOC_GAM")
-        super(SourceCatalog1FHL, self).__init__(
+        super().__init__(
             table=table,
             source_name_key=source_name_key,
             source_name_alias=source_name_alias,
@@ -1083,7 +1168,7 @@ class SourceCatalog1FHL(SourceCatalog):
 class SourceCatalog2FHL(SourceCatalog):
     """Fermi-LAT 2FHL source catalog.
 
-    Reference: http://adsabs.harvard.edu/abs/2016ApJS..222....5A
+    Reference: https://ui.adsabs.harvard.edu/abs/2016ApJS..222....5A
 
     One source is represented by `~gammapy.catalog.SourceCatalogObject2FHL`.
     """
@@ -1103,7 +1188,7 @@ class SourceCatalog2FHL(SourceCatalog):
 
         source_name_key = "Source_Name"
         source_name_alias = ("ASSOC", "3FGL_Name", "1FHL_Name", "TeVCat_Name")
-        super(SourceCatalog2FHL, self).__init__(
+        super().__init__(
             table=table,
             source_name_key=source_name_key,
             source_name_alias=source_name_alias,
@@ -1117,7 +1202,7 @@ class SourceCatalog2FHL(SourceCatalog):
 class SourceCatalog3FHL(SourceCatalog):
     """Fermi-LAT 3FHL source catalog.
 
-    Reference: http://adsabs.harvard.edu/abs/2017ApJS..232...18A
+    Reference: https://ui.adsabs.harvard.edu/abs/2017ApJS..232...18A
 
     One source is represented by `~gammapy.catalog.SourceCatalogObject3FHL`.
     """
@@ -1144,7 +1229,7 @@ class SourceCatalog3FHL(SourceCatalog):
 
         source_name_key = "Source_Name"
         source_name_alias = ("ASSOC1", "ASSOC2", "ASSOC_TEV", "ASSOC_GAM")
-        super(SourceCatalog3FHL, self).__init__(
+        super().__init__(
             table=table,
             source_name_key=source_name_key,
             source_name_alias=source_name_alias,
@@ -1160,7 +1245,7 @@ class SourceCatalog3FHL(SourceCatalog):
 
         The classes are described in Table 3 of the 3FGL paper:
 
-        http://adsabs.harvard.edu/abs/2015arXiv150102003T
+        https://ui.adsabs.harvard.edu/abs/2015ApJS..218...23A
 
         Parameters
         ----------
@@ -1191,7 +1276,7 @@ class SourceCatalog3FHL(SourceCatalog):
         elif source_class == "all":
             category = set(cats["extra-galactic"] + cats["galactic"])
         elif source_class in np.unique(source_class_info):
-            category = set([source_class])
+            category = {source_class}
         else:
             raise ValueError("Invalid source_class: {!r}".format(source_class))
 
