@@ -3,13 +3,11 @@
 
 https://github.com/gammapy/gamma-cat
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 from collections import OrderedDict, namedtuple
 import functools
 import logging
 import json
 import numpy as np
-from ..extern import six
 from astropy import units as u
 from astropy.table import Table
 from ..utils.scripts import make_path
@@ -31,17 +29,11 @@ log = logging.getLogger(__name__)
 
 
 class NoDataAvailableError(LookupError):
-    """Generic error used in Gammapy, when some data isn't available.
-    """
-
-    pass
+    """Generic error used in Gammapy, when some data isn't available."""
 
 
 class GammaCatNotFoundError(OSError):
-    """The gamma-cat repo is not available.
-    """
-
-    pass
+    """The gamma-cat repo is not available."""
 
 
 class SourceCatalogObjectGammaCat(SourceCatalogObject):
@@ -64,7 +56,6 @@ class SourceCatalogObjectGammaCat(SourceCatalogObject):
         info : {'all', 'basic', 'position, 'model'}
             Comma separated list of options
         """
-
         if info == "all":
             info = "basic,position,model"
 
@@ -462,7 +453,7 @@ class SourceCatalogGammaCat(SourceCatalog):
 
         source_name_key = "common_name"
         source_name_alias = ("other_names", "gamma_names")
-        super(SourceCatalogGammaCat, self).__init__(
+        super().__init__(
             table=table,
             source_name_key=source_name_key,
             source_name_alias=source_name_alias,
@@ -488,7 +479,7 @@ class SourceCatalogGammaCat(SourceCatalog):
         return SkyModels(source_list)
 
 
-class GammaCatDataCollection(object):
+class GammaCatDataCollection:
     """Data store for gamma-cat.
 
     Gives access to all data from https://github.com/gammapy/gamma-cat .
@@ -517,7 +508,7 @@ class GammaCatDataCollection(object):
 
 
 @functools.total_ordering
-class GammaCatResource(object):
+class GammaCatResource:
     """Reference for a single resource in gamma-cat.
 
     This can be considered an implementation detail,
@@ -554,10 +545,10 @@ class GammaCatResource(object):
         self, source_id, reference_id, file_id=-1, type="none", location="none"
     ):
         self.source_id = int(source_id)
-        self.reference_id = six.text_type(reference_id)
+        self.reference_id = str(reference_id)
         self.file_id = int(file_id)
-        self.type = six.text_type(type)
-        self.location = six.text_type(location)
+        self.type = str(type)
+        self.location = str(location)
 
     @property
     def global_id(self):
@@ -613,7 +604,7 @@ class GammaCatResource(object):
         )
 
 
-class GammaCatResourceIndex(object):
+class GammaCatResourceIndex:
     """Resource index for gamma-cat.
 
     Parameters
@@ -636,12 +627,12 @@ class GammaCatResourceIndex(object):
     @property
     def unique_source_ids(self):
         """Sorted list of unique source IDs (list of int)."""
-        return sorted(set([resource.source_id for resource in self.resources]))
+        return sorted({resource.source_id for resource in self.resources})
 
     @property
     def unique_reference_ids(self):
         """Sorted list of unique source IDs (list of str)."""
-        return sorted(set([resource.reference_id for resource in self.resources]))
+        return sorted({resource.reference_id for resource in self.resources})
 
     @property
     def global_ids(self):
