@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """HESS Galactic plane survey (HGPS) catalog."""
-from __future__ import absolute_import, division, print_function, unicode_literals
 from collections import OrderedDict
 import numpy as np
 import astropy.units as u
@@ -33,10 +32,10 @@ FLUX_TO_CRAB = 100 / 2.26e-11
 FLUX_TO_CRAB_DIFF = 100 / 3.5060459323111307e-11
 
 
-class SourceCatalogObjectHGPSComponent(object):
+class SourceCatalogObjectHGPSComponent:
     """One Gaussian component from the HGPS catalog.
 
-    See also
+    See Also
     --------
     SourceCatalogHGPS, SourceCatalogObjectHGPS
     """
@@ -548,13 +547,19 @@ class SourceCatalogObjectHGPS(SourceCatalogObject):
                 spectral_model_comp = spectral_model.copy()
                 # weight amplitude of the component
                 spectral_model_comp.parameters["amplitude"].value *= weight
-                models.append(SkyModel(component.spatial_model, spectral_model_comp))
+                models.append(
+                    SkyModel(
+                        component.spatial_model,
+                        spectral_model_comp,
+                        name=component.name,
+                    )
+                )
 
             return SkyModels(models)
         else:
             spatial_model = self.spatial_model
             spectral_model = self.spectral_model(which=which)
-            return SkyModel(spatial_model, spectral_model)
+            return SkyModel(spatial_model, spectral_model, name=self.name)
 
     @property
     def flux_points(self):
@@ -635,9 +640,7 @@ class SourceCatalogHGPS(SourceCatalog):
         table = Table.read(filename, hdu=hdu)
 
         source_name_alias = ("Identified_Object",)
-        super(SourceCatalogHGPS, self).__init__(
-            table=table, source_name_alias=source_name_alias
-        )
+        super().__init__(table=table, source_name_alias=source_name_alias)
 
         self._table_components = Table.read(filename, hdu="HGPS_GAUSS_COMPONENTS")
         self._table_associations = Table.read(filename, hdu="HGPS_ASSOCIATIONS")
@@ -673,7 +676,7 @@ class SourceCatalogHGPS(SourceCatalog):
 
     def _make_source_object(self, index):
         """Make `SourceCatalogObject` for given row index"""
-        source = super(SourceCatalogHGPS, self)._make_source_object(index)
+        source = super()._make_source_object(index)
 
         if source.data["Components"] != "":
             self._attach_component_info(source)
@@ -709,7 +712,7 @@ class SourceCatalogHGPS(SourceCatalog):
         return SourceCatalogObjectHGPSComponent(data=data)
 
 
-class SourceCatalogLargeScaleHGPS(object):
+class SourceCatalogLargeScaleHGPS:
     """Gaussian band model.
 
     This 2-dimensional model is Gaussian in ``y`` for a given ``x``,
@@ -738,16 +741,14 @@ class SourceCatalogLargeScaleHGPS(object):
 
         for column in table.colnames:
             values = self.table[column].quantity
-            interp = ScaledRegularGridInterpolator(
-                (glon.degree,), values, **interp_kwargs
-            )
+            interp = ScaledRegularGridInterpolator((glon,), values, **interp_kwargs)
             interps[column] = interp
 
         self._interp = interps
 
     def _interpolate_parameter(self, parname, glon):
         glon = glon.wrap_at("180d")
-        return self._interp[parname]((np.asanyarray(glon.degree),), clip=False)
+        return self._interp[parname]((np.asanyarray(glon),), clip=False)
 
     def peak_brightness(self, glon):
         """Peak brightness at a given longitude.
