@@ -1,11 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 from astropy.table import Table
 
 __all__ = ["source_catalogs", "SourceCatalogRegistry"]
 
 
-class SourceCatalogRegistry(object):
+class SourceCatalogRegistry:
     """Source catalog registry.
 
     Provides simple and efficient access to source catalogs
@@ -22,9 +21,7 @@ class SourceCatalogRegistry(object):
 
     @classmethod
     def builtins(cls):
-        """Factory function that make a catalog registry and
-        registers the built-in catalogs.
-        """
+        """Create a catalog registry containing the built-in catalogs."""
         source_catalogs = cls()
 
         from .hess import SourceCatalogHGPS
