@@ -11,14 +11,40 @@ from ...spectrum.models import (
     LogParabola,
     ExponentialCutoffPowerLaw3FGL,
     PLSuperExpCutoff3FGL,
+    PLSuperExpCutoff4FGL,
 )
 from .. import (
+    SourceCatalog4FGL,
     SourceCatalog3FGL,
     SourceCatalog2FHL,
     SourceCatalog1FHL,
     SourceCatalog3FHL,
 )
 
+SOURCES_4FGL = [
+    dict(
+        idx=0,
+        name="4FGL J0000.3-7355",
+        spec_type=PowerLaw,
+        dnde=u.Quantity(2.9476e-11, "cm-2 s-1 GeV-1"),
+        dnde_err=u.Quantity(5.3318e-12, "cm-2 s-1 GeV-1"),
+    ),
+    dict(
+        idx=3,
+        name="4FGL J0001.5+2113",
+        spec_type=LogParabola,
+        dnde=u.Quantity(2.8545e-8, "cm-2 s-1 GeV-1"),
+        dnde_err=u.Quantity(1.3324e-9, "cm-2 s-1 GeV-1"),
+    ),
+    dict(
+        idx=7,
+        name="4FGL J0002.8+6217",
+        spec_type=PLSuperExpCutoff4FGL,
+        dnde=u.Quantity(2.084e-09, "cm-2 s-1 GeV-1"),
+        dnde_err=u.Quantity(1.0885e-10, "cm-2 s-1 GeV-1"),
+    ),
+]
+
 SOURCES_3FGL = [
     dict(
         idx=0,
@@ -68,6 +94,24 @@ SOURCES_3FHL = [
 ]
 
 
+@requires_data()
+class TestFermi4FGLObject:
+    @classmethod
+    def setup_class(cls):
+        cls.cat = SourceCatalog4FGL()
+
+    @requires_dependency("uncertainties")
+    @pytest.mark.parametrize("ref", SOURCES_4FGL, ids=lambda _: _["name"])
+    def test_spectral_model(self, ref):
+        model = self.cat[ref["idx"]].spectral_model
+
+        e_ref = model.reference.quantity
+        dnde, dnde_err = model.evaluate_error(e_ref)
+        assert isinstance(model, ref["spec_type"])
+        assert_quantity_allclose(dnde, ref["dnde"], rtol=1e-4)
+        assert_quantity_allclose(dnde_err, ref["dnde_err"], rtol=1e-4)
+
+
 @requires_data()
 class TestFermi3FGLObject:
     @classmethod
@@ -86,6 +130,11 @@ class TestFermi3FGLObject:
     def test_data(self):
         assert_allclose(self.source.data["Signif_Avg"], 30.669872283935547)
 
+    def test_position(self):
+        position = self.source.position
+        assert_allclose(position.ra.deg, 83.637199, atol=1e-3)
+        assert_allclose(position.dec.deg, 22.024099, atol=1e-3)
+
     def test_str(self):
         ss = str(self.source)
         assert "Source name          : 3FGL J0534.5+2201" in ss
@@ -201,6 +250,11 @@ class TestFermi1FHLObject:
     def test_name(self):
         assert self.source.name == self.source_name
 
+    def test_position(self):
+        position = self.source.position
+        assert_allclose(position.ra.deg, 83.628098, atol=1e-3)
+        assert_allclose(position.dec.deg, 22.0191, atol=1e-3)
+
     def test_spectral_model(self):
         model = self.source.spectral_model
         energy = u.Quantity(100, "GeV")
@@ -232,6 +286,11 @@ class TestFermi2FHLObject:
     def test_name(self):
         assert self.source.name == self.source_name
 
+    def test_position(self):
+        position = self.source.position
+        assert_allclose(position.ra.deg, 83.634102, atol=1e-3)
+        assert_allclose(position.dec.deg, 22.0215, atol=1e-3)
+
     def test_spectral_model(self):
         model = self.source.spectral_model
         energy = u.Quantity(100, "GeV")
@@ -286,6 +345,11 @@ class TestFermi3FHLObject:
         assert isinstance(data["Flux_Band"][0], float)
         assert_allclose(data["Flux_Band"][0], 5.1698894054652555e-09)
 
+    def test_position(self):
+        position = self.source.position
+        assert_allclose(position.ra.deg, 83.634834, atol=1e-3)
+        assert_allclose(position.dec.deg, 22.019203, atol=1e-3)
+
     @requires_dependency("uncertainties")
     @pytest.mark.parametrize("ref", SOURCES_3FHL, ids=lambda _: _["name"])
     def test_spectral_model(self, ref):
