@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 from collections import OrderedDict
 from numpy.testing import assert_allclose
 import pytest
@@ -24,6 +23,8 @@ SOURCES = [
         "n_flux_points": 24,
         "is_pointlike": False,
         "spatial_model": "SkyGaussian",
+        "ra": 128.287003,
+        "dec": -45.189999,
     },
     {
         "name": "HESS J1848-018",
@@ -37,6 +38,8 @@ SOURCES = [
         "n_flux_points": 11,
         "is_pointlike": False,
         "spatial_model": "SkyGaussian",
+        "ra": 282.119995,
+        "dec": -1.792,
     },
     {
         "name": "HESS J1813-178",
@@ -50,6 +53,8 @@ SOURCES = [
         "n_flux_points": 13,
         "is_pointlike": False,
         "spatial_model": "SkyGaussian",
+        "ra": 273.362915,
+        "dec": -17.84889,
     },
 ]
 
@@ -60,12 +65,15 @@ def gammacat():
     return SourceCatalogGammaCat(filename=filename)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 class TestSourceCatalogGammaCat:
     def test_source_table(self, gammacat):
         assert gammacat.name == "gamma-cat"
         assert len(gammacat.table) == 162
 
+    def test_positions(self, gammacat):
+        assert len(gammacat.positions) == 162
+
     def test_w28_alias_names(self, gammacat):
         names = [
             "W28",
@@ -96,7 +104,7 @@ class TestSourceCatalogGammaCat:
         assert_allclose(source.spectral_model.parameters["index"].value, 2.2)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 class TestSourceCatalogObjectGammaCat:
     def test_data(self, gammacat):
         source = gammacat[0]
@@ -166,6 +174,15 @@ class TestSourceCatalogObjectGammaCat:
 
         assert len(flux_points.table) == ref["n_flux_points"]
 
+    @pytest.mark.parametrize("ref", SOURCES, ids=lambda _: _["name"])
+    def test_position(self, gammacat, ref):
+        source = gammacat[ref["name"]]
+
+        position = source.position
+
+        assert_allclose(position.ra.deg, ref["ra"], atol=1e-3)
+        assert_allclose(position.dec.deg, ref["dec"], atol=1e-3)
+
     @pytest.mark.parametrize("ref", SOURCES, ids=lambda _: _["name"])
     def test_spatial_model(self, gammacat, ref):
         source = gammacat[ref["name"]]
