@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 from ...utils.testing import requires_data
 from ..registry import SourceCatalogRegistry
@@ -15,14 +14,13 @@ def source_catalogs():
     return cats
 
 
-# 2HWC catalog is in ECSV format, which requires yaml to read the header
-@requires_data("gammapy-data")
+@requires_data()
 def test_info_table(source_catalogs):
     table = source_catalogs.info_table
     assert table.colnames == ["name", "description", "sources"]
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_getitem(source_catalogs):
     cat = source_catalogs["2fhl"]
     assert cat.name == "2fhl"
@@ -41,4 +39,4 @@ def test_register(source_catalogs):
 
 def test_source_catalogs(source_catalogs):
     """Test the global registry instance"""
-    assert set(["3fgl", "2fhl"]).issubset(source_catalogs.catalog_names)
+    assert {"3fgl", "2fhl"}.issubset(source_catalogs.catalog_names)
