@@ -22,7 +22,7 @@ class DataStore:
     The data selection and access happens using an observation
     and an HDU index file as described at :ref:`gadf:iact-storage`.
 
-    See :gp-notebook:`cta_1dc_introduction` for usage examples.
+    For a usage example see :gp-notebook:`cta_1dc_introduction`
 
     Parameters
     ----------
@@ -308,7 +308,7 @@ class DataStore:
             if not overwrite:
                 cmd += ["-n"]
             cmd += [str(loc.path()), str(targetdir)]
-            subprocess.call(cmd)
+            subprocess.run(cmd)
 
         filename = str(outdir / self.DEFAULT_HDU_TABLE)
         subhdutable.write(filename, format="fits", overwrite=overwrite)
@@ -374,7 +374,7 @@ class DataStoreChecker(Checker):
                 }
 
     def check_consistency(self):
-        """Consistency checks between multiple HDUs"""
+        """Check consistency between multiple HDUs."""
         # obs and HDU index should have the same OBS_ID
         obs_table_obs_id = set(self.data_store.obs_table["OBS_ID"])
         hdu_table_obs_id = set(self.data_store.hdu_table["OBS_ID"])
