@@ -7,11 +7,12 @@ from astropy.coordinates import SkyCoord, Angle, AltAz
 from astropy.coordinates.angle_utilities import angular_separation
 from astropy.table import Table
 from astropy.table import vstack as vstack_tables
-from ..utils.energy import EnergyBounds
+from ..utils.energy import energy_logspace
 from ..utils.fits import earth_location_from_dict
 from ..utils.scripts import make_path
 from ..utils.time import time_ref_from_dict
 from ..utils.testing import Checker
+from ..utils.regions import make_region
 
 __all__ = ["EventListBase", "EventList", "EventListLAT"]
 
@@ -120,7 +121,7 @@ class EventListBase:
 
     @property
     def time_ref(self):
-        """Time reference (`~astropy.time.Time`)"""
+        """Time reference (`~astropy.time.Time`)."""
         return time_ref_from_dict(self.table.meta)
 
     @property
@@ -183,7 +184,7 @@ class EventListBase:
         Dead-time is defined as the time during the observation
         where the detector didn't record events:
         https://en.wikipedia.org/wiki/Dead_time
-        https://adsabs.harvard.edu/abs/2004APh....22..285F
+        https://ui.adsabs.harvard.edu/abs/2004APh....22..285F
 
         The dead-time fraction is used in the live-time computation,
         which in turn is used in the exposure and flux computation.
@@ -283,103 +284,27 @@ class EventListBase:
         mask &= time < time_interval[1]
         return self.select_row_subset(mask)
 
-    def select_sky_cone(self, center, radius):
-        """Select events in sky circle.
+    def select_region(self, region, wcs=None):
+        """Select events in given region.
 
         Parameters
         ----------
-        center : `~astropy.coordinates.SkyCoord`
-            Sky circle center
-        radius : `~astropy.coordinates.Angle`
-            Sky circle radius
+        region : `~regions.SkyRegion` or str
+            Sky region or string defining a sky region
+        wcs : `~astropy.wcs.WCS`
+            World coordinate system transformation
 
         Returns
         -------
         event_list : `EventList`
             Copy of event list with selection applied.
         """
-        position = self.radec
-        separation = center.separation(position)
-        mask = separation < radius
+        region = make_region(region)
+        mask = region.contains(self.radec, wcs)
         return self.select_row_subset(mask)
 
-    def select_sky_ring(self, center, inner_radius, outer_radius):
-        """Select events in ring region on the sky.
-
-        Parameters
-        ----------
-        center : `~astropy.coordinates.SkyCoord`
-            Sky ring center
-        inner_radius, outer_radius : `~astropy.coordinates.Angle`
-            Sky ring inner and outer radius
-
-        Returns
-        -------
-        event_list : `EventList`
-            Copy of event list with selection applied.
-        """
-        position = self.radec
-        separation = center.separation(position)
-        mask1 = inner_radius < separation
-        mask2 = separation < outer_radius
-        mask = mask1 * mask2
-        return self.select_row_subset(mask)
-
-    def select_sky_box(self, lon_lim, lat_lim, frame="icrs"):
-        """Select events in sky box.
-
-        TODO: move `gammapy.catalog.select_sky_box` to gammapy.utils.
-        """
-        from ..catalog import select_sky_box
-
-        selected = select_sky_box(self.table, lon_lim, lat_lim, frame)
-        return self.__class__(selected)
-
-    def select_circular_region(self, region):
-        """Select events in circular regions.
-
-        TODO: Extend to support generic regions
-
-        Parameters
-        ----------
-        region : `~regions.CircleSkyRegion` or list of `~regions.CircleSkyRegion`
-            (List of) sky region(s)
-
-        Returns
-        -------
-        event_list : `EventList`
-            Copy of event list with selection applied.
-        """
-        if not isinstance(region, list):
-            region = list([region])
-        mask = self.filter_circular_region(region)
-        return self.select_row_subset(mask)
-
-    def filter_circular_region(self, region):
-        """Create selection mask for event in given circular regions.
-
-        TODO: Extend to support generic regions
-
-        Parameters
-        ----------
-        region : list of `~regions.SkyRegion`
-            List of sky regions
-
-        Returns
-        -------
-        index_array : `numpy.ndarray`
-            Index array of selected events
-        """
-        position = self.radec
-        mask = np.array([], dtype=int)
-        for reg in region:
-            separation = reg.center.separation(position)
-            temp = np.where(separation < reg.radius)[0]
-            mask = np.union1d(mask, temp)
-        return mask
-
     def select_parameter(self, parameter, band):
-        """Select events with respect to a specified parameter
+        """Select events with respect to a specified parameter.
 
         Parameters
         ----------
@@ -407,7 +332,7 @@ class EventListBase:
 
     def _default_plot_ebounds(self):
         energy = self.energy
-        return EnergyBounds.equal_log_spacing(energy.min(), energy.max(), 50)
+        return energy_logspace(energy.min(), energy.max(), 50)
 
     def _counts_spectrum(self, ebounds):
         from ..spectrum import CountsSpectrum
@@ -599,7 +524,7 @@ class EventListBase:
 
 
 class EventList(EventListBase):
-    """Event list for IACT dataset
+    """Event list for IACT dataset.
 
     Data format specification: :ref:`gadf:iact-events`
 
@@ -627,6 +552,7 @@ class EventList(EventListBase):
     @property
     def observation_time_duration(self):
         """Observation time duration in seconds (`~astropy.units.Quantity`).
+
         This is a keyword related to IACTs
         The wall time, including dead-time.
         """
@@ -635,13 +561,14 @@ class EventList(EventListBase):
     @property
     def observation_dead_time_fraction(self):
         """Dead-time fraction (float).
+
         This is a keyword related to IACTs
         Defined as dead-time over observation time.
 
         Dead-time is defined as the time during the observation
         where the detector didn't record events:
         http://en.wikipedia.org/wiki/Dead_time
-        http://adsabs.harvard.edu/abs/2004APh....22..285F
+        https://ui.adsabs.harvard.edu/abs/2004APh....22..285F
 
         The dead-time fraction is used in the live-time computation,
         which in turn is used in the exposure and flux computation.
@@ -655,12 +582,12 @@ class EventList(EventListBase):
 
     @property
     def altaz(self):
-        """ALT / AZ position computed from RA / DEC (`~astropy.coordinates.SkyCoord`)"""
+        """ALT / AZ position computed from RA / DEC (`~astropy.coordinates.SkyCoord`)."""
         return self.radec.transform_to(self.altaz_frame)
 
     @property
     def altaz_from_table(self):
-        """ALT / AZ position from table (`~astropy.coordinates.SkyCoord`)"""
+        """ALT / AZ position from table (`~astropy.coordinates.SkyCoord`)."""
         lon = self.table["AZ"]
         lat = self.table["ALT"]
         return SkyCoord(lon, lat, unit="deg", frame=self.altaz_frame)
@@ -747,7 +674,7 @@ class EventList(EventListBase):
 
 
 class EventListLAT(EventListBase):
-    """Event list for Fermi-LAT dataset
+    """Event list for Fermi-LAT dataset.
 
     Fermi-LAT data products
     https://fermi.gsfc.nasa.gov/ssc/data/analysis/documentation/Cicerone/Cicerone_Data/LAT_DP.html
