@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import logging
 import numpy as np
 from collections import OrderedDict
@@ -12,13 +11,14 @@ from ..utils.fits import earth_location_from_dict
 from ..utils.table import table_row_to_dict
 from ..utils.time import time_ref_from_dict
 from .filters import ObservationFilter
+from .pointing import FixedPointingInfo
 
 __all__ = ["DataStoreObservation", "Observations"]
 
 log = logging.getLogger(__name__)
 
 
-class DataStoreObservation(object):
+class DataStoreObservation:
     """IACT data store observation.
 
     Parameters
@@ -184,7 +184,7 @@ class DataStoreObservation(object):
         Dead-time is defined as the time during the observation
         where the detector didn't record events:
         https://en.wikipedia.org/wiki/Dead_time
-        https://adsabs.harvard.edu/abs/2004APh....22..285F
+        https://ui.adsabs.harvard.edu/abs/2004APh....22..285F
 
         The dead-time fraction is used in the live-time computation,
         which in turn is used in the exposure and flux computation.
@@ -208,6 +208,11 @@ class DataStoreObservation(object):
         """Pointing zenith angle sky (`~astropy.units.Quantity`)."""
         return Quantity(self.obs_info["ZEN_PNT"], unit="deg")
 
+    @property
+    def fixed_pointing_info(self):
+        """Fixed pointing info for this observation (`FixedPointingInfo`)."""
+        return FixedPointingInfo(self.events.table.meta)
+
     @property
     def target_radec(self):
         """Target RA / DEC sky coordinates (`~astropy.coordinates.SkyCoord`)."""
@@ -258,7 +263,7 @@ class DataStoreObservation(object):
         return checker.run(checks=checks)
 
 
-class Observations(object):
+class Observations:
     """Container class that holds a list of observations.
 
     Parameters
@@ -268,13 +273,13 @@ class Observations(object):
     """
 
     def __init__(self, obs_list=None):
-        self._obs_list = obs_list or []
+        self.list = obs_list or []
 
     def __getitem__(self, key):
-        return self._obs_list[key]
+        return self.list[key]
 
     def __len__(self):
-        return len(self._obs_list)
+        return len(self.list)
 
     def __str__(self):
         s = self.__class__.__name__ + "\n"
@@ -335,8 +340,7 @@ class ObservationChecker(Checker):
             yield self._record(level="warning", msg="Loading events failed")
             return
 
-        for record in EventListChecker(events).run():
-            yield record
+        yield from EventListChecker(events).run()
 
     # TODO: split this out into a GTIChecker
     def check_gti(self):
@@ -433,7 +437,7 @@ class ObservationChecker(Checker):
         yield self._record(level="debug", msg="Starting psf check")
 
         try:
-            psf = self.observation.load("psf")
+            self.observation.load("psf")
         except Exception:
             yield self._record(level="warning", msg="Loading psf failed")
             return
