@@ -1,13 +1,15 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 from numpy.testing import assert_allclose
 from astropy.time import Time
+import astropy.units as u
+from astropy.table import Table
 from ...utils.testing import requires_data, assert_time_allclose
 from ...data import GTI
+from ...utils.time import time_ref_to_dict
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_gti_hess():
     filename = "$GAMMAPY_DATA/tests/unbundled/hess/run_0023037_hard_eventlist.fits.gz"
     gti = GTI.read(filename)
@@ -25,7 +27,7 @@ def test_gti_hess():
     assert_time_allclose(gti.time_stop[0], expected)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_gti_fermi():
     filename = "$GAMMAPY_DATA/fermi-3fhl-gc/fermi-3fhl-gc-events.fits.gz"
     gti = GTI.read(filename)
@@ -43,7 +45,7 @@ def test_gti_fermi():
     assert_time_allclose(gti.time_stop[0], expected)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 @pytest.mark.parametrize(
     "time_interval, expected_length, expected_times",
     [
@@ -85,3 +87,30 @@ def test_select_time(time_interval, expected_length, expected_times):
         expected_times.format = "mjd"
         assert_time_allclose(gti_selected.time_start[0], expected_times[0])
         assert_time_allclose(gti_selected.time_stop[-1], expected_times[1])
+
+
+def make_gti(times, time_ref="2010-01-01"):
+    meta = time_ref_to_dict(time_ref)
+    table = Table(times, meta=meta)
+    return GTI(table)
+
+
+def test_gti_stack():
+    time_ref = Time("2010-01-01")
+    gti1 = make_gti({"START": [0, 2], "STOP": [1, 3]}, time_ref=time_ref)
+    gti2 = make_gti({"START": [4], "STOP": [5]}, time_ref=time_ref + 10 * u.s)
+
+    gti = gti1.stack(gti2)
+
+    assert_time_allclose(gti.time_ref, gti1.time_ref)
+    assert_allclose(gti.table["START"], [0, 2, 14])
+    assert_allclose(gti.table["STOP"], [1, 3, 15])
+
+
+def test_gti_union():
+    gti = make_gti({"START": [5, 6, 1, 2], "STOP": [8, 7, 3, 4]})
+
+    gti = gti.union()
+
+    assert_allclose(gti.table["START"], [1, 5])
+    assert_allclose(gti.table["STOP"], [4, 8])
