@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
@@ -37,7 +36,7 @@ def kbe():
     )
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_run_iteration(kbe, images):
     result = kbe.run_iteration(images)
     mask, background = result["exclusion"].data, result["background"].data
@@ -52,7 +51,7 @@ def test_run_iteration(kbe, images):
     assert_allclose(background, 42 * np.ones((10, 10)))
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_run(kbe, images):
     result = kbe.run(images)
     mask, background = result["exclusion"].data, result["background"].data
@@ -62,7 +61,7 @@ def test_run(kbe, images):
     assert len(kbe.images_stack) == 4
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_run_without_defaults(kbe, images):
     result = kbe.run({"counts": images["counts"]})
     mask, background = result["exclusion"].data, result["background"].data
