@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Helper functions and functions for plotting gamma-ray images."""
-from __future__ import absolute_import, division, print_function, unicode_literals
 from collections import OrderedDict
 import numpy as np
 from astropy.coordinates import Angle
@@ -16,15 +15,14 @@ __all__ = [
 __doctest_requires__ = {("colormap_hess", "colormap_milagro"): ["matplotlib"]}
 
 
-class MapPanelPlotter(object):
+class MapPanelPlotter:
     """
-    Mape panel plotter class.
+    Map panel plotter class.
 
     Given a `~matplotlib.pyplot.Figure` object this class creates axes objects
     using `~matplotlib.gridspec.GridSpec` and plots a given sky map onto these.
 
-    An example of how this class is used can be found in the :gp-notebook:`hgps`
-    notebook at the end.
+    For a usage example see :gp-notebook:`hgps` (at the end).
 
     Parameters
     ----------
@@ -83,9 +81,9 @@ class MapPanelPlotter(object):
         ax.set_ylim(*ylim_pix)
         return ax
 
-    def plot_panel(self, image, panel=1, panel_fov=None, **kwargs):
+    def plot_panel(self, map, panel=1, panel_fov=None, **kwargs):
         """
-        Plot sky image on one panel.
+        Plot sky map on one panel.
 
         Parameters
         ----------
@@ -97,27 +95,27 @@ class MapPanelPlotter(object):
         if panel_fov is None:
             panel_fov = panel
         spec = self.grid_spec[panel]
-        ax = self.figure.add_subplot(spec, projection=image.geom.wcs)
+        ax = self.figure.add_subplot(spec, projection=map.geom.wcs)
         try:
-            ax = image.plot(ax=ax, **kwargs)[1]
+            ax = map.plot(ax=ax, **kwargs)[1]
         except AttributeError:
-            ax = image.plot_rgb(ax=ax, **kwargs)
+            ax = map.plot_rgb(ax=ax, **kwargs)
         ax = self._set_ax_fov(ax, panel_fov)
         return ax
 
-    def plot(self, image, **kwargs):
+    def plot(self, map, **kwargs):
         """
-        Plot sky image on all panels.
+        Plot sky map on all panels.
 
         Parameters
         ----------
-       map : `~gammapy.maps.WcsNDMap`
+        map : `~gammapy.maps.WcsNDMap`
             Map to plot.
         """
         p = self.parameters
         axes = []
         for panel in range(p["npanels"]):
-            ax = self.plot_panel(image, panel=panel, **kwargs)
+            ax = self.plot_panel(map, panel=panel, **kwargs)
             axes.append(ax)
         return axes
 
@@ -292,7 +290,6 @@ def grayify_colormap(cmap, mode="hsp"):
 
     References
     ----------
-
     .. [1] Darel Rex Finley, "HSP Color Model - Alternative to HSV (HSB) and HSL"
        http://alienryderflex.com/hsp.html
 
