@@ -7,7 +7,7 @@ from astropy.table import Table
 from ..utils.nddata import NDDataArray
 from ..maps import MapAxis
 from ..maps.utils import edges_from_lo_hi
-from ..utils.energy import EnergyBounds
+from ..utils.energy import energy_logcenter
 from ..utils.scripts import make_path
 
 __all__ = ["EffectiveAreaTable", "EffectiveAreaTable2D"]
@@ -123,14 +123,14 @@ class EffectiveAreaTable:
 
     @classmethod
     def from_parametrization(cls, energy, instrument="HESS"):
-        """Get parametrized effective area.
+        r"""Get parametrized effective area.
 
         Parametrizations of the effective areas of different Cherenkov
         telescopes taken from Appendix B of Abramowski et al. (2010), see
-        http://adsabs.harvard.edu/abs/2010MNRAS.402.1342A .
+        https://ui.adsabs.harvard.edu/abs/2010MNRAS.402.1342A .
 
         .. math::
-            A_{eff}(E) = g_1 \\left(\\frac{E}{\\mathrm{MeV}}\\right)^{-g_2}\\exp{\\left(-\\frac{g_3}{E}\\right)}
+            A_{eff}(E) = g_1 \left(\frac{E}{\mathrm{MeV}}\right)^{-g_2}\exp{\left(-\frac{g_3}{E}\right)}
 
         Parameters
         ----------
@@ -139,7 +139,7 @@ class EffectiveAreaTable:
         instrument : {'HESS', 'HESS2', 'CTA'}
             Instrument name
         """
-        energy = EnergyBounds(energy)
+        energy = u.Quantity(energy)
         # Put the parameters g in a dictionary.
         # Units: g1 (cm^2), g2 (), g3 (MeV)
         # Note that whereas in the paper the parameter index is 1-based,
@@ -155,7 +155,7 @@ class EffectiveAreaTable:
             ss += "Valid instruments: HESS, HESS2, CTA"
             raise ValueError(ss)
 
-        xx = energy.log_centers.to_value("MeV")
+        xx = energy_logcenter(energy).to_value("MeV")
 
         g1 = pars[instrument][0]
         g2 = pars[instrument][1]
@@ -164,9 +164,7 @@ class EffectiveAreaTable:
         value = g1 * xx ** (-g2) * np.exp(g3 / xx)
         data = u.Quantity(value, "cm2", copy=False)
 
-        return cls(
-            energy_lo=energy.lower_bounds, energy_hi=energy.upper_bounds, data=data
-        )
+        return cls(energy_lo=energy[:-1], energy_hi=energy[1:], data=data)
 
     @classmethod
     def from_table(cls, table):
@@ -441,11 +439,10 @@ class EffectiveAreaTable2D:
         if energy is None:
             energy = self.data.axis("energy").edges
 
-        energy = EnergyBounds(energy)
-        area = self.data.evaluate(offset=offset, energy=energy.log_centers)
+        area = self.data.evaluate(offset=offset, energy=energy_logcenter(energy))
 
         return EffectiveAreaTable(
-            energy_lo=energy.lower_bounds, energy_hi=energy.upper_bounds, data=area
+            energy_lo=energy[:-1], energy_hi=energy[1:], data=area
         )
 
     def plot_energy_dependence(self, ax=None, offset=None, energy=None, **kwargs):
@@ -500,7 +497,7 @@ class EffectiveAreaTable2D:
             Axis
         offset : `~astropy.coordinates.Angle`
             Offset axis
-        energy : `~gammapy.utils.energy.Energy`
+        energy : `~astropy.units.Quantity`
             Energy
 
         Returns
