@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import logging
 import numpy as np
 from astropy.units import Quantity
@@ -10,7 +9,7 @@ __all__ = ["IRFStacker"]
 log = logging.getLogger(__name__)
 
 
-class IRFStacker(object):
+class IRFStacker:
     r"""
     Stack instrument response functions.
 
@@ -22,7 +21,6 @@ class IRFStacker(object):
     and :math:`l` denote a bin in reconstructed and true energy, respectively.
 
     .. math::
-
         \epsilon_{jk} =\left\{\begin{array}{cl} 1, & \mbox{if
             bin k is inside the energy thresholds}\\ 0, & \mbox{otherwise} \end{array}\right.
 
@@ -69,7 +67,7 @@ class IRFStacker(object):
         """
         Compute mean effective area (`~gammapy.irf.EffectiveAreaTable`).
         """
-        nbins = self.list_aeff[0].energy.nbins
+        nbins = self.list_aeff[0].energy.nbin
         aefft = Quantity(np.zeros(nbins), "cm2 s")
         livetime_tot = np.sum(self.list_livetime)
 
@@ -79,18 +77,18 @@ class IRFStacker(object):
             aefft += aefft_current
 
         stacked_data = aefft / livetime_tot
+
+        energy = self.list_aeff[0].energy.edges
         self.stacked_aeff = EffectiveAreaTable(
-            energy_lo=self.list_aeff[0].energy.lo,
-            energy_hi=self.list_aeff[0].energy.hi,
-            data=stacked_data.to("cm2"),
+            energy_lo=energy[:-1], energy_hi=energy[1:], data=stacked_data.to("cm2")
         )
 
     def stack_edisp(self):
         """
         Compute mean energy dispersion (`~gammapy.irf.EnergyDispersion`).
         """
-        reco_bins = self.list_edisp[0].e_reco.nbins
-        true_bins = self.list_edisp[0].e_true.nbins
+        reco_bins = self.list_edisp[0].e_reco.nbin
+        true_bins = self.list_edisp[0].e_true.nbin
 
         aefft = Quantity(np.zeros(true_bins), "cm2 s")
         temp = np.zeros(shape=(reco_bins, true_bins))
@@ -109,10 +107,12 @@ class IRFStacker(object):
         with np.errstate(divide="ignore", invalid="ignore"):
             stacked_edisp = np.nan_to_num(aefftedisp / aefft)
 
+        e_true = self.list_edisp[0].e_true.edges
+        e_reco = self.list_edisp[0].e_reco.edges
         self.stacked_edisp = EnergyDispersion(
-            e_true_lo=self.list_edisp[0].e_true.lo,
-            e_true_hi=self.list_edisp[0].e_true.hi,
-            e_reco_lo=self.list_edisp[0].e_reco.lo,
-            e_reco_hi=self.list_edisp[0].e_reco.hi,
+            e_true_lo=e_true[:-1],
+            e_true_hi=e_true[1:],
+            e_reco_lo=e_reco[:-1],
+            e_reco_hi=e_reco[1:],
             data=stacked_edisp.transpose(),
         )
