@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
 import pytest
 from astropy.coordinates import Angle
@@ -14,7 +13,7 @@ def psf_king():
     return PSFKing.read(filename)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_psf_king_evaluate(psf_king):
     param_off1 = psf_king.evaluate(energy="1 TeV", offset="0 deg")
     param_off2 = psf_king.evaluate("1 TeV", "1 deg")
@@ -25,7 +24,7 @@ def test_psf_king_evaluate(psf_king):
     assert_quantity_allclose(param_off2["sigma"], psf_king.sigma[2, 8])
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_psf_king_to_table(psf_king):
     theta1 = Angle(0, "deg")
     theta2 = Angle(1, "deg")
@@ -53,7 +52,7 @@ def test_psf_king_to_table(psf_king):
     assert_quantity_allclose(integral, 1, atol=0.03)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_psf_king_write(psf_king, tmpdir):
     filename = str(tmpdir / "king.fits")
     psf_king.write(filename)
