@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import abc
 import copy
 import inspect
@@ -7,22 +6,15 @@ import json
 from collections import OrderedDict
 import numpy as np
 from astropy import units as u
-from astropy.utils.misc import InheritDocstrings
 from astropy.io import fits
 from .geom import pix_tuple_to_idx, MapCoord
-from .utils import unpack_seq
-from ..extern import six
+from .utils import INVALID_VALUE
 from ..utils.scripts import make_path
 
 __all__ = ["Map"]
 
 
-class MapMeta(InheritDocstrings, abc.ABCMeta):
-    pass
-
-
-@six.add_metaclass(MapMeta)
-class Map(object):
+class Map(abc.ABC):
     """Abstract map class.
 
     This can represent WCS- or HEALPIX-based maps
@@ -53,7 +45,7 @@ class Map(object):
     def _init_copy(self, **kwargs):
         """Init map instance by copying missing init arguments from self.
         """
-        argnames = inspect.getargspec(self.__init__).args
+        argnames = inspect.getfullargspec(self.__init__).args
         argnames.remove("self")
         argnames.remove("dtype")
 
@@ -331,78 +323,27 @@ class Map(object):
         hdulist.writeto(filename, overwrite=overwrite)
 
     def iter_by_image(self):
-        """Iterate over image planes of the map returning a tuple with the image
-        array and image plane index.
+        """Iterate over image planes of the map.
+
+        This is a generator yielding ``(data, idx)`` tuples,
+        where ``data`` is a `numpy.ndarray` view of the image plane data,
+        and ``idx`` is a tuple of int, the index of the image plane.
 
         The image plane index is in data order, so that the data array can be
         indexed directly. See :ref:`mapiter` for further information.
-
-        Returns
-        -------
-        val : `~numpy.ndarray`
-            Array of image plane values.
-        idx : tuple
-            Index of image plane.
         """
-        for idx in np.ndindex(self.geom.shape):
+        for idx in np.ndindex(self.geom.shape_axes):
             yield self.data[idx[::-1]], idx[::-1]
 
-    def iter_by_pix(self, buffersize=1):
-        """Iterate over elements of the map returning a tuple with values and
-        pixel coordinates.
-
-        Parameters
-        ----------
-        buffersize : int
-            Set the size of the buffer.  The map will be returned in
-            chunks of the given size.
-
-        Returns
-        -------
-        val : `~numpy.ndarray`
-            Map values.
-        pix : tuple
-            Tuple of pixel coordinates.
-        """
-        pix = list(self.geom.get_idx(flat=True))
-        vals = self.data[np.isfinite(self.data)]
-        x = [vals] + pix
-        return unpack_seq(
-            np.nditer(x, flags=["external_loop", "buffered"], buffersize=buffersize)
-        )
-
-    def iter_by_coord(self, buffersize=1):
-        """Iterate over elements of the map returning a tuple with values and
-        map coordinates.
-
-        Parameters
-        ----------
-        buffersize : int
-            Set the size of the buffer.  The map will be returned in
-            chunks of the given size.
-
-        Returns
-        -------
-        val : `~numpy.ndarray`
-            Map values.
-        coords : tuple
-            Tuple of map coordinates.
-        """
-        coords = list(self.geom.get_coord(flat=True))
-        vals = self.data[np.isfinite(self.data)]
-        x = [vals] + coords
-        return unpack_seq(
-            np.nditer(x, flags=["external_loop", "buffered"], buffersize=buffersize)
-        )
-
     @abc.abstractmethod
     def sum_over_axes(self, keepdims=False):
         """Reduce to a 2D image by summing over non-spatial dimensions."""
         pass
 
     def coadd(self, map_in):
-        """Add the contents of ``map_in`` to this map.  This method can be
-        used to combine maps containing integral quantities (e.g. counts)
+        """Add the contents of ``map_in`` to this map.
+
+        This method can be used to combine maps containing integral quantities (e.g. counts)
         or differential quantities if the maps have the same binning.
 
         Parameters
@@ -464,8 +405,7 @@ class Map(object):
 
     @abc.abstractmethod
     def pad(self, pad_width, mode="constant", cval=0, order=1):
-        """Pad the spatial dimension of the map by extending the edge of the
-        map by the given number of pixels.
+        """Pad the spatial dimensions of the map.
 
         Parameters
         ----------
@@ -491,8 +431,7 @@ class Map(object):
 
     @abc.abstractmethod
     def crop(self, crop_width):
-        """Crop the spatial dimension of the map by removing a number of
-        pixels from the edge of the map.
+        """Crop the spatial dimensions of the map.
 
         Parameters
         ----------
@@ -508,7 +447,7 @@ class Map(object):
         pass
 
     @abc.abstractmethod
-    def downsample(self, factor, preserve_counts=True):
+    def downsample(self, factor, preserve_counts=True, axis=None):
         """Downsample the spatial dimension by a given factor.
 
         Parameters
@@ -519,6 +458,8 @@ class Map(object):
             Preserve the integral over each bin.  This should be true
             if the map is an integral quantity (e.g. counts) and false if
             the map is a differential quantity (e.g. intensity).
+        axis : str
+            Which axis to downsample. By default spatial axes are downsampled.
 
         Returns
         -------
@@ -528,7 +469,7 @@ class Map(object):
         pass
 
     @abc.abstractmethod
-    def upsample(self, factor, order=0, preserve_counts=True):
+    def upsample(self, factor, order=0, preserve_counts=True, axis=None):
         """Upsample the spatial dimension by a given factor.
 
         Parameters
@@ -541,12 +482,14 @@ class Map(object):
             Preserve the integral over each bin.  This should be true
             if the map is an integral quantity (e.g. counts) and false if
             the map is a differential quantity (e.g. intensity).
+        axis : str
+            Which axis to upsample. By default spatial axes are upsampled.
+
 
         Returns
         -------
         map : `Map`
             Upsampled map.
-
         """
         pass
 
@@ -583,9 +526,17 @@ class Map(object):
             for non-spatial dimensions of the map. Dict should specify the axis
             names of the non-spatial axes such as {'axes0': x_0, ..., 'axesn': x_n}.
 
+        Returns
+        -------
+        map_out : `Map`
+            Map with spatial dimensions only.
+
+        See Also
+        --------
+        get_image_by_idx, get_image_by_pix
+
         Examples
         --------
-
         ::
 
             import numpy as np
@@ -622,15 +573,6 @@ class Map(object):
 
             # Get image by coord dict with quantities
             image = m_wcs.get_image_by_coord({'energy': 0.5 * u.TeV, 'time': 1 * u.h})
-
-        See Also
-        --------
-        get_image_by_idx, get_image_by_pix
-
-        Returns
-        -------
-        map_out : `Map`
-            Map with spatial dimensions only.
         """
         if isinstance(coords, tuple):
             axes_names = [_.name for _ in self.geom.axes]
@@ -710,12 +652,8 @@ class Map(object):
            outside of map.
         """
         coords = MapCoord.create(coords, coordsys=self.geom.coordsys)
-        msk = self.geom.contains(coords)
-        vals = np.empty(coords.shape, dtype=self.data.dtype)
-        coords = coords.apply_mask(msk)
-        idx = self.geom.coord_to_idx(coords)
-        vals[msk] = self.get_by_idx(idx)
-        vals[~msk] = np.nan
+        pix = self.geom.coord_to_pix(coords)
+        vals = self.get_by_pix(pix)
         return vals
 
     def get_by_pix(self, pix):
@@ -730,21 +668,23 @@ class Map(object):
             Pixel indices can be either float or integer type.
 
         Returns
-        ----------
+        -------
         vals : `~numpy.ndarray`
            Array of pixel values.  np.nan used to flag coordinates
            outside of map
         """
         # FIXME: Support local indexing here?
         # FIXME: Support slicing?
-        pix = [np.array(p, copy=False, ndmin=1) for p in pix]
         pix = np.broadcast_arrays(*pix)
-        msk = self.geom.contains_pix(pix)
-        vals = np.empty(pix[0].shape, dtype=self.data.dtype)
-        pix = tuple([p[msk] for p in pix])
         idx = self.geom.pix_to_idx(pix)
-        vals[msk] = self.get_by_idx(idx)
-        vals[~msk] = np.nan
+        vals = self.get_by_idx(idx)
+        mask = self.geom.contains_pix(pix)
+
+        if not mask.all():
+            invalid = INVALID_VALUE[self.data.dtype]
+            vals = vals.astype(type(invalid))
+            vals[~mask] = invalid
+
         return vals
 
     @abc.abstractmethod
@@ -759,7 +699,7 @@ class Map(object):
             for WCS maps and (I_hpx, I_0, ..., I_n) for HEALPix maps.
 
         Returns
-        ----------
+        -------
         vals : `~numpy.ndarray`
            Array of pixel values.
            np.nan used to flag coordinate outside of map
@@ -1011,7 +951,7 @@ class Map(object):
             Keyword arguments to overwrite in the map constructor.
 
         Returns
-        --------
+        -------
         copy : `Map`
             Copied Map.
         """
@@ -1034,7 +974,7 @@ class Map(object):
         return str_
 
     def _arithmetics(self, operator, other, copy):
-        """ Perform arithmetics on maps after checking geometry consistency"""
+        """Perform arithmetics on maps after checking geometry consistency."""
         if isinstance(other, Map):
             if self.geom == other.geom:
                 q = other.quantity
@@ -1070,3 +1010,6 @@ class Map(object):
 
     def __itruediv__(self, other):
         return self._arithmetics(np.true_divide, other, copy=False)
+
+    def __array__(self):
+        return self.data
