@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import abc
 import copy
 import inspect
@@ -8,13 +7,12 @@ from collections import OrderedDict
 import logging
 import numpy as np
 from scipy.interpolate import interp1d
-from astropy.utils.misc import InheritDocstrings
 from astropy.io import fits
 from astropy import units as u
 from astropy.coordinates import SkyCoord
-from ..extern import six
+from astropy.table import QTable, Column
 from ..utils.interpolation import interpolation_scale
-from .utils import find_hdu, find_bands_hdu
+from .utils import find_hdu, find_bands_hdu, INVALID_INDEX
 
 __all__ = ["MapCoord", "MapGeom", "MapAxis"]
 
@@ -170,21 +168,19 @@ def coordsys_to_frame(coordsys):
         raise ValueError("Unrecognized coordinate system: {!r}".format(coordsys))
 
 
+# TODO: remove (or improve)
 def skycoord_to_lonlat(skycoord, coordsys=None):
-    """
+    """Convert SkyCoord to lon, lat, frame.
 
     Returns
     -------
     lon : `~numpy.ndarray`
         Longitude in degrees.
-
     lat : `~numpy.ndarray`
         Latitude in degrees.
-
     frame : str
         Name of coordinate frame.
     """
-
     if coordsys in ["CEL", "C"]:
         skycoord = skycoord.transform_to("icrs")
     elif coordsys in ["GAL", "G"]:
@@ -204,20 +200,19 @@ def lonlat_to_skycoord(lon, lat, coordsys):
 
 
 def pix_tuple_to_idx(pix):
-    """Convert a tuple of pixel coordinate arrays to a tuple of pixel
-    indices.
+    """Convert a tuple of pixel coordinate arrays to a tuple of pixel indices.
 
     Pixel coordinates are rounded to the closest integer value.
 
     Parameters
     ----------
     pix : tuple
-        Tuple of pixel coordinates with one element for each dimension.
+        Tuple of pixel coordinates with one element for each dimension
 
     Returns
     -------
     idx : `~numpy.ndarray`
-        Array of pixel indices.
+        Array of pixel indices
     """
     idx = []
     for p in pix:
@@ -226,21 +221,19 @@ def pix_tuple_to_idx(pix):
             idx += [p]
         else:
             p_idx = np.rint(p).astype(int)
-            p_idx[~np.isfinite(p)] = -1
+            p_idx[~np.isfinite(p)] = INVALID_INDEX.int
             idx += [p_idx]
 
     return tuple(idx)
 
 
 def axes_pix_to_coord(axes, pix):
-    """Perform pixel to axis coordinates for a list of `~MapAxis`
-    objects.
+    """Perform pixel to axis coordinates for a list of `~MapAxis` objects.
 
     Parameters
     ----------
     axes : list
         List of `~MapAxis`.
-
     pix : tuple
         Tuple of pixel coordinates.
     """
@@ -264,9 +257,9 @@ def coord_to_idx(edges, x, clip=False):
         ibin[x > edges[-1]] = len(edges) - 1
     else:
         with np.errstate(invalid="ignore"):
-            ibin[x > edges[-1]] = -1
+            ibin[x > edges[-1]] = INVALID_INDEX.int
 
-    ibin[~np.isfinite(x)] = -1
+    ibin[~np.isfinite(x)] = INVALID_INDEX.int
     return ibin
 
 
@@ -276,8 +269,7 @@ def bin_to_val(edges, bins):
 
 
 def coord_to_pix(edges, coord, interp="lin"):
-    """Convert axis coordinates to pixel coordinates using the chosen
-    interpolation scheme."""
+    """Convert axis to pixel coordinates for given interpolation scheme."""
     scale = interpolation_scale(interp)
 
     interp_fn = interp1d(
@@ -288,8 +280,7 @@ def coord_to_pix(edges, coord, interp="lin"):
 
 
 def pix_to_coord(edges, pix, interp="lin"):
-    """Convert pixel coordinates to grid coordinates using the chosen
-    interpolation scheme."""
+    """Convert pixel to grid coordinates for given interpolation scheme."""
     scale = interpolation_scale(interp)
 
     interp_fn = interp1d(
@@ -299,7 +290,7 @@ def pix_to_coord(edges, pix, interp="lin"):
     return scale.inverse(interp_fn(pix))
 
 
-class MapAxis(object):
+class MapAxis:
     """Class representing an axis of a map.
 
     Provides methods for
@@ -312,7 +303,7 @@ class MapAxis(object):
 
     Parameters
     ----------
-    nodes : `~numpy.ndarray`
+    nodes : `~numpy.ndarray` or `~astropy.units.Quantity`
         Array of node values.  These will be interpreted as either bin
         edges or centers according to ``node_type``.
     interp : str
@@ -346,12 +337,32 @@ class MapAxis(object):
     # TODO: Cache an interpolation object?
 
     def __init__(self, nodes, interp="lin", name="", node_type="edges", unit=""):
+
         self.name = name
+
+        if len(nodes) != len(np.unique(nodes)):
+            raise ValueError("MapAxis: node values must be unique")
+        if ~(np.all(nodes == np.sort(nodes)) or np.all(nodes[::-1] == np.sort(nodes))):
+            raise ValueError("MapAxis: node values must be sorted")
+
+        if isinstance(nodes, u.Quantity):
+            unit = nodes.unit if nodes.unit is not None else ""
+            nodes = nodes.value
+        else:
+            nodes = np.array(nodes)
+
         self.unit = unit
         self._nodes = nodes
         self._node_type = node_type
         self._interp = interp
 
+        if (self._nodes < 0).any() and interp != "lin":
+            raise ValueError(
+                "Interpolation scaling '{}' only support for positive node values.".format(
+                    interp
+                )
+            )
+
         # Set pixel coordinate of first node
         if node_type == "edges":
             self._pix_offset = -0.5
@@ -365,17 +376,18 @@ class MapAxis(object):
         self._nbin = nbin
 
     def __eq__(self, other):
-        """Test axis equality. Absolute and relative tolerances of 1e-6 are used"""
         if not isinstance(other, self.__class__):
             return NotImplemented
 
         # TODO: implement an allclose method for MapAxis and call it here
         if self.edges.shape != other.edges.shape:
             return False
-
+        if self.unit.is_equivalent(other.unit) is False:
+            return False
         return (
-            np.allclose(self.edges, other.edges, atol=1e-6, rtol=1e-6)
-            and self.unit == other.unit
+            np.allclose(
+                self.edges.to(other.unit).value, other.edges.value, atol=1e-6, rtol=1e-6
+            )
             and self._node_type == other._node_type
             and self._interp == other._interp
             and self.name.upper() == other.name.upper()
@@ -384,6 +396,11 @@ class MapAxis(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    @property
+    def interp(self):
+        """Interpolation scale of the axis."""
+        return self._interp
+
     @property
     def name(self):
         """Name of the axis."""
@@ -397,13 +414,13 @@ class MapAxis(object):
     def edges(self):
         """Return array of bin edges."""
         pix = np.arange(self.nbin + 1, dtype=float) - 0.5
-        return self.pix_to_coord(pix)
+        return u.Quantity(self.pix_to_coord(pix), self._unit, copy=False)
 
     @property
     def center(self):
         """Return array of bin centers."""
         pix = np.arange(self.nbin, dtype=float)
-        return self.pix_to_coord(pix)
+        return u.Quantity(self.pix_to_coord(pix), self._unit, copy=False)
 
     @property
     def nbin(self):
@@ -483,7 +500,6 @@ class MapAxis(object):
             Interpolation method used to transform between axis and pixel
             coordinates.  Default: 'lin'.
         """
-        nodes = np.array(nodes, ndmin=1)
         if len(nodes) < 1:
             raise ValueError("Nodes array must have at least one element.")
 
@@ -561,7 +577,7 @@ class MapAxis(object):
             Array of bin indices.
         """
         coord = u.Quantity(coord, self.unit, copy=False).value
-        return coord_to_idx(self.edges, coord, clip)
+        return coord_to_idx(self.edges.value, coord, clip)
 
     def slice(self, idx):
         """Create a new axis object by extracting a slice from this axis.
@@ -576,7 +592,7 @@ class MapAxis(object):
         axis : `~MapAxis`
             Sliced axis object.
         """
-        center = self.center[idx]
+        center = self.center[idx].value
         idx = self.coord_to_idx(center)
         # For edge nodes we need to keep N+1 nodes
         if self._node_type == "edges":
@@ -602,8 +618,8 @@ class MapAxis(object):
         # TODO: Decide on handling node_type=center
         # See https://github.com/gammapy/gammapy/issues/1952
         return MapAxis.from_bounds(
-            lo_bnd=self.edges[0],
-            hi_bnd=self.edges[-1],
+            lo_bnd=self.edges[0].value,
+            hi_bnd=self.edges[-1].value,
             nbin=1,
             interp=self._interp,
             name=self._name,
@@ -619,23 +635,157 @@ class MapAxis(object):
         str_ += fmt.format("nbins", str(self.nbin))
         str_ += fmt.format("node type", self.node_type)
         vals = self.edges if self.node_type == "edges" else self.center
-        str_ += fmt.format(
-            "{} min".format(self.node_type),
-            "{:.1e} {}".format(vals.min(), str(self.unit)),
-        )
-        str_ += fmt.format(
-            "{} max".format(self.node_type),
-            "{:.1e} {}".format(vals.max(), str(self.unit)),
-        )
+        str_ += fmt.format("{} min".format(self.node_type), "{:.1e}".format(vals.min()))
+        str_ += fmt.format("{} max".format(self.node_type), "{:.1e}".format(vals.max()))
         str_ += fmt.format("interp", self._interp)
         return str_
 
-    def copy(self):
-        """Copy `MapAxis` object"""
-        return copy.deepcopy(self)
+    def _init_copy(self, **kwargs):
+        """Init map axis instance by copying missing init arguments from self.
+        """
+        argnames = inspect.getfullargspec(self.__init__).args
+        argnames.remove("self")
+
+        for arg in argnames:
+            value = getattr(self, "_" + arg)
+            kwargs.setdefault(arg, copy.deepcopy(value))
+
+        return self.__class__(**kwargs)
+
+    def copy(self, **kwargs):
+        """Copy `MapAxis` instance and overwrite given attributes.
+
+        Parameters
+        ----------
+        **kwargs : dict
+            Keyword arguments to overwrite in the map axis constructor.
+
+        Returns
+        -------
+        copy : `MapAxis`
+            Copied map axis.
+        """
+        return self._init_copy(**kwargs)
+
+    def group_table(self, edges):
+        """Compute bin groups table for the map axis, given coarser bin edges.
+
+        Parameters
+        ----------
+        edges : `~astropy.units.Quantity`
+            Group bin edges.
+
+        Returns
+        -------
+        groups : `~astropy.table.Table`
+            Map axis group table.
+        """
+        # TODO: try to simplify this code
+        if not self.node_type == "edges":
+            raise ValueError("Only edge based map axis can be grouped")
+
+        edges_pix = self.coord_to_pix(edges)
+        edges_pix = np.clip(edges_pix, -0.5, self.nbin - 0.5)
+        edges_idx = np.round(edges_pix + 0.5) - 0.5
+        edges_idx = np.unique(edges_idx)
+        edges_ref = self.pix_to_coord(edges_idx) * self.unit
+
+        groups = QTable()
+        groups["{}_min".format(self.name)] = edges_ref[:-1]
+        groups["{}_max".format(self.name)] = edges_ref[1:]
+
+        groups["idx_min"] = (edges_idx[:-1] + 0.5).astype(int)
+        groups["idx_max"] = (edges_idx[1:] - 0.5).astype(int)
+
+        if len(groups) == 0:
+            raise ValueError("No overlap between reference and target edges.")
+
+        groups["bin_type"] = "normal   "
+
+        edge_idx_start, edge_ref_start = edges_idx[0], edges_ref[0]
+        if edge_idx_start > 0:
+            underflow = {
+                "bin_type": "underflow",
+                "idx_min": 0,
+                "idx_max": edge_idx_start,
+                "{}_min".format(self.name): self.pix_to_coord(-0.5) * self.unit,
+                "{}_max".format(self.name): edge_ref_start,
+            }
+            groups.insert_row(0, vals=underflow)
+
+        edge_idx_end, edge_ref_end = edges_idx[-1], edges_ref[-1]
+
+        if edge_idx_end < (self.nbin - 0.5):
+            overflow = {
+                "bin_type": "overflow",
+                "idx_min": edge_idx_end + 1,
+                "idx_max": self.nbin - 1,
+                "{}_min".format(self.name): edge_ref_end,
+                "{}_max".format(self.name): self.pix_to_coord(self.nbin - 0.5)
+                * self.unit,
+            }
+            groups.add_row(vals=overflow)
+
+        group_idx = Column(np.arange(len(groups)))
+        groups.add_column(group_idx, name="group_idx", index=0)
+        return groups
+
+    def _up_down_sample(self, nbin):
+        if self.node_type == "edges":
+            nodes = self.edges
+        else:
+            nodes = self.center
+
+        lo_bnd, hi_bnd = nodes.min(), nodes.max()
+
+        return self.from_bounds(
+            lo_bnd=lo_bnd.value,
+            hi_bnd=hi_bnd.value,
+            nbin=nbin,
+            interp=self.interp,
+            node_type=self.node_type,
+            unit=self.unit,
+            name=self.name,
+        )
+
+    def upsample(self, factor):
+        """Upsample map axis by a given factor.
+
+        Parameters
+        ----------
+        factor : int
+            Upsampling factor.
 
 
-class MapCoord(object):
+        Returns
+        -------
+        axis : `MapAxis`
+            Usampled map axis.
+
+        """
+        nbin = self.nbin * factor
+        return self._up_down_sample(nbin)
+
+    def downsample(self, factor):
+        """Downsample map axis by a given factor.
+
+        Parameters
+        ----------
+        factor : int
+            Downsampling factor.
+
+
+        Returns
+        -------
+        axis : `MapAxis`
+            Downsampled map axis.
+
+        """
+        nbin = int(self.nbin / factor)
+        return self._up_down_sample(nbin)
+
+
+class MapCoord:
     """Represents a sequence of n-dimensional map coordinates.
 
     Contains coordinates for 2 spatial dimensions and an arbitrary
@@ -674,7 +824,7 @@ class MapCoord(object):
         self._match_by_name = match_by_name
 
     def __getitem__(self, key):
-        if isinstance(key, six.string_types):
+        if isinstance(key, str):
             return self._data[key]
         else:
             return list(self._data.values())[key]
@@ -708,24 +858,22 @@ class MapCoord(object):
 
     @property
     def theta(self):
-        """Theta co-latitude angle in radians"""
+        """Theta co-latitude angle in radians."""
         return np.pi / 2.0 - np.radians(self.lat)
 
     @property
     def phi(self):
-        """Phi longitude angle in radians"""
+        """Phi longitude angle in radians."""
         return np.radians(self.lon)
 
     @property
     def coordsys(self):
-        """Coordinate system (str)"""
+        """Coordinate system (str)."""
         return self._coordsys
 
     @property
     def match_by_name(self):
-        """Boolean flag indicating whether axis lookup should be performed by
-        name (True) or index (False).
-        """
+        """Boolean flag: axis lookup by name (True) or index (False)."""
         return self._match_by_name
 
     @property
@@ -942,12 +1090,7 @@ class MapCoord(object):
         return self.__class__(coords, coordsys=self.coordsys)
 
 
-class MapGeomMeta(InheritDocstrings, abc.ABCMeta):
-    pass
-
-
-@six.add_metaclass(MapGeomMeta)
-class MapGeom(object):
+class MapGeom(abc.ABC):
     """Base class for WCS and HEALPix geometries."""
 
     @property
@@ -1163,8 +1306,9 @@ class MapGeom(object):
 
     @abc.abstractmethod
     def pix_to_idx(self, pix, clip=False):
-        """Convert pixel coordinates to pixel indices.  Returns -1 for pixel
-        coordinates that lie outside of the map.
+        """Convert pixel coordinates to pixel indices.
+
+        Returns -1 for pixel coordinates that lie outside of the map.
 
         Parameters
         ----------
@@ -1212,11 +1356,10 @@ class MapGeom(object):
             Bool array.
         """
         idx = self.pix_to_idx(pix)
-        return np.all(np.stack([t != -1 for t in idx]), axis=0)
+        return np.all(np.stack([t != INVALID_INDEX.int for t in idx]), axis=0)
 
     def slice_by_idx(self, slices):
-        """Create a new geometry by cutting in the non-spatial dimensions of
-        this geometry.
+        """Create a new geometry by slicing the non-spatial axes.
 
         Parameters
         ----------
@@ -1243,8 +1386,7 @@ class MapGeom(object):
 
     @abc.abstractmethod
     def to_image(self):
-        """Create a 2D geometry by dropping all non-spatial dimensions of this
-        geometry.
+        """Create 2D image geometry (drop non-spatial dimensions).
 
         Returns
         -------
@@ -1255,8 +1397,9 @@ class MapGeom(object):
 
     @abc.abstractmethod
     def to_cube(self, axes):
-        """Create a new geometry by appending a list of non-spatial axes to
-        the present geometry.  This will result in a new geometry with
+        """Append non-spatial axes to create a higher-dimensional geometry.
+
+        This will result in a new geometry with
         N+M dimensions where N is the number of current dimensions and
         M is the number of axes in the list.
 
@@ -1326,13 +1469,15 @@ class MapGeom(object):
         pass
 
     @abc.abstractmethod
-    def downsample(self, factor):
+    def downsample(self, factor, axis):
         """Downsample the spatial dimension of the geometry by a given factor.
 
         Parameters
         ----------
         factor : int
             Downsampling factor.
+        axis : str
+            Axis to downsample.
 
         Returns
         -------
@@ -1343,13 +1488,15 @@ class MapGeom(object):
         pass
 
     @abc.abstractmethod
-    def upsample(self, factor):
+    def upsample(self, factor, axis):
         """Upsample the spatial dimension of the geometry by a given factor.
 
         Parameters
         ----------
         factor : int
             Upsampling factor.
+        axis : str
+            Axis to upsample.
 
         Returns
         -------
@@ -1422,9 +1569,9 @@ class MapGeom(object):
         return names.index(name.upper())
 
     def _init_copy(self, **kwargs):
-        """Init map instance by copying missing init arguments from self.
+        """Init map geom instance by copying missing init arguments from self.
         """
-        argnames = inspect.getargspec(self.__init__).args
+        argnames = inspect.getfullargspec(self.__init__).args
         argnames.remove("self")
 
         for arg in argnames:
@@ -1442,8 +1589,30 @@ class MapGeom(object):
             Keyword arguments to overwrite in the map geometry constructor.
 
         Returns
-        --------
+        -------
         copy : `MapGeom`
             Copied map geometry.
         """
         return self._init_copy(**kwargs)
+
+    def energy_mask(self, emin=None, emax=None):
+        """Create a mask for a given energy range.
+
+        Parameters
+        ----------
+        emin, emax : `~astropy.units.Quantity`
+            Energy range
+        """
+        # get energy axes and values
+        energy_axis = self.get_axis_by_name("energy")
+        edges = energy_axis.edges
+
+        # set default values
+        emin = emin if emin is not None else edges[0]
+        emax = emax if emax is not None else edges[-1]
+
+        # create mask
+        coords = self.get_coord()
+        mask = coords["energy"] > emin.to_value(energy_axis.unit)
+        mask &= coords["energy"] < emax.to_value(energy_axis.unit)
+        return mask
