@@ -1,6 +1,5 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Utilities for dealing with HEALPix projections and mappings."""
-from __future__ import absolute_import, division, print_function, unicode_literals
 from collections import OrderedDict
 import re
 import copy
@@ -8,7 +7,7 @@ import numpy as np
 from astropy.io import fits
 from astropy.coordinates import SkyCoord
 from astropy.units import Quantity
-from ..extern import six
+from .utils import INVALID_INDEX
 from .wcs import WcsGeom
 from .geom import MapGeom, MapCoord, pix_tuple_to_idx
 from .geom import coordsys_to_frame, skycoord_to_lonlat
@@ -25,7 +24,7 @@ HPX_ORDER_TO_PIXSIZE = np.array(
 )
 
 
-class HpxConv(object):
+class HpxConv:
     """Data structure to define how a HEALPIX map is stored to FITS."""
 
     def __init__(self, convname, **kwargs):
@@ -309,8 +308,7 @@ def make_hpx_to_wcs_mapping(hpx, wcs):
 
 
 def match_hpx_pix(nside, nest, nside_pix, ipix_ring):
-    """TODO
-    """
+    """TODO: document."""
     import healpy as hp
 
     ipix_in = np.arange(12 * nside * nside)
@@ -435,7 +433,6 @@ def get_superpixels(idx, nside_subpix, nside_superpix, nest=True):
         Indices of HEALpix pixels of nside ``nside_superpix`` that
         contain pixel indices ``idx`` of nside ``nside_subpix``.
     """
-
     import healpy as hp
 
     idx = np.array(idx)
@@ -452,16 +449,17 @@ def get_superpixels(idx, nside_subpix, nside_superpix, nest=True):
     idx //= ratio
 
     if not nest:
-        m = idx == -1
+        m = idx == INVALID_INDEX.int
         idx[m] = 0
         idx = hp.nest2ring(nside_superpix, idx)
-        idx[m] = -1
+        idx[m] = INVALID_INDEX.int
 
     return idx
 
 
 def get_subpixels(idx, nside_superpix, nside_subpix, nest=True):
     """Compute the indices of subpixels contained within superpixels.
+
     This function returns an output array with one additional
     dimension of size N for subpixel indices where N is the maximum
     number of subpixels for any pair of ``nside_superpix`` and
@@ -507,15 +505,15 @@ def get_subpixels(idx, nside_superpix, nside_subpix, nest=True):
     if not np.all(npix[0] == npix):
         x = np.broadcast_to(x, idx.shape + x.shape)
         idx = idx[..., None] + x
-        idx[x >= np.broadcast_to(npix[..., None], x.shape)] = -1
+        idx[x >= np.broadcast_to(npix[..., None], x.shape)] = INVALID_INDEX.int
     else:
         idx = idx[..., None] + x
 
     if not nest:
-        m = idx == -1
+        m = idx == INVALID_INDEX.int
         idx[m] = 0
         idx = hp.nest2ring(nside_subpix[..., None], idx)
-        idx[m] = -1
+        idx[m] = INVALID_INDEX.int
 
     return idx
 
@@ -580,8 +578,7 @@ class HpxGeom(MapGeom):
 
         self._nside = np.array(nside, ndmin=1)
         self._axes = make_axes(axes, conv)
-        self._shape = tuple([ax.nbin for ax in self._axes])
-        if self.nside.size > 1 and self.nside.shape != self._shape:
+        if self.nside.size > 1 and self.nside.shape != self.shape_axes:
             raise ValueError(
                 "Wrong dimensionality for nside. nside must "
                 "be a scalar or have a dimensionality consistent "
@@ -592,7 +589,7 @@ class HpxGeom(MapGeom):
         self._nest = nest
         self._coordsys = coordsys
         self._maxpix = 12 * self._nside * self._nside
-        self._maxpix = self._maxpix * np.ones(self._shape, dtype=int)
+        self._maxpix = self._maxpix * np.ones(self.shape_axes, dtype=int)
         self._sparse = sparse
 
         self._ipix = None
@@ -605,7 +602,7 @@ class HpxGeom(MapGeom):
             for i, ipix in enumerate(self._ipix.flat):
                 self._rmap[ipix] = i
 
-        self._npix = self._npix * np.ones(self._shape, dtype=int)
+        self._npix = self._npix * np.ones(self.shape_axes, dtype=int)
         self._conv = conv
         self._center_skydir = self._get_ref_dir()
         lon, lat, frame = skycoord_to_lonlat(self._center_skydir)
@@ -624,8 +621,7 @@ class HpxGeom(MapGeom):
 
     def _create_lookup(self, region):
         """Create local-to-global pixel lookup table."""
-
-        if isinstance(region, six.string_types):
+        if isinstance(region, str):
             ipix = [
                 self.get_index_list(nside, self._nest, region)
                 for nside in self._nside.flat
@@ -658,8 +654,8 @@ class HpxGeom(MapGeom):
             if len(region) == 1:
                 self._npix = np.array([len(region[0])])
             else:
-                self._npix = np.zeros(self._shape, dtype=int)
-                idx = np.ravel_multi_index(region[1:], self._shape)
+                self._npix = np.zeros(self.shape_axes, dtype=int)
+                idx = np.ravel_multi_index(region[1:], self.shape_axes)
                 cnt = np.unique(idx, return_counts=True)
                 self._npix.flat[cnt[0]] = cnt[1]
 
@@ -672,14 +668,12 @@ class HpxGeom(MapGeom):
             raise ValueError("Invalid region string: {!r}".format(region))
 
     def local_to_global(self, idx_local):
-        """Compute a local index (partial-sky) from a global (all-sky)
-        index.
+        """Compute a local index (partial-sky) from a global (all-sky) index.
 
         Returns
         -------
         idx_global : tuple
-            A tuple of pixel index vectors with global HEALPIX pixel
-            indices.
+            A tuple of pixel index vectors with global HEALPIX pixel indices
         """
         if self._ipix is None:
             return idx_local
@@ -728,9 +722,9 @@ class HpxGeom(MapGeom):
         else:
             idx_local = unravel_hpx_index(retval, self._npix)
 
-        m = np.any(np.stack([t == -1 for t in idx_local]), axis=0)
+        m = np.any(np.stack([t == INVALID_INDEX.int for t in idx_local]), axis=0)
         for i, t in enumerate(idx_local):
-            idx_local[i][m] = -1
+            idx_local[i][m] = INVALID_INDEX.int
 
         if not ravel:
             return idx_local
@@ -738,7 +732,7 @@ class HpxGeom(MapGeom):
             return ravel_hpx_index(idx_local, self.npix)
 
     def __getitem__(self, idx_global):
-        """This implements the global-to-local index lookup.
+        """Implement global-to-local index lookup.
 
         For all-sky maps it just returns the input array.  For
         partial-sky maps it returns the local indices corresponding to
@@ -800,7 +794,7 @@ class HpxGeom(MapGeom):
             pix = tuple([pix] + bins)
             if np.any(m):
                 for p in pix:
-                    p[m] = -1
+                    p[m] = INVALID_INDEX.int
         else:
             pix = (hp.ang2pix(self.nside, theta, phi, nest=self.nest),)
 
@@ -824,14 +818,14 @@ class HpxGeom(MapGeom):
                 nside = self.nside
 
             ipix = np.round(pix[0]).astype(int)
-            m = ipix == -1
+            m = ipix == INVALID_INDEX.int
             ipix[m] = 0
             theta, phi = hp.pix2ang(nside, ipix, nest=self.nest)
             coords = [np.degrees(phi), np.degrees(np.pi / 2.0 - theta)]
             coords = tuple(coords + vals)
             if np.any(m):
                 for c in coords:
-                    c[m] = np.nan
+                    c[m] = INVALID_INDEX.float
         else:
             ipix = np.round(pix[0]).astype(int)
             theta, phi = hp.pix2ang(self.nside, ipix, nest=self.nest)
@@ -869,7 +863,7 @@ class HpxGeom(MapGeom):
         if len(slices) != self.ndim - 2:
             raise ValueError()
 
-        nside = np.ones(self.shape, dtype=int) * self.nside
+        nside = np.ones(self.shape_axes, dtype=int) * self.nside
         nside = np.squeeze(nside[slices])
 
         axes = [ax.slice(s) for ax, s in zip(self.axes, slices)]
@@ -883,7 +877,7 @@ class HpxGeom(MapGeom):
             idx = self.get_idx()
             slices = (slice(None),) + slices
             idx = [p[slices[::-1]] for p in idx]
-            idx = [p[p != -1] for p in idx]
+            idx = [p[p != INVALID_INDEX.int] for p in idx]
             if drop_axes:
                 idx = [idx[i] for i in range(len(idx)) if i in slice_dims]
             region = tuple(idx)
@@ -898,9 +892,9 @@ class HpxGeom(MapGeom):
         return self._axes
 
     @property
-    def shape(self):
+    def shape_axes(self):
         """Shape of non-spatial axes."""
-        return self._shape
+        return tuple([ax.nbin for ax in self._axes])
 
     @property
     def ndim(self):
@@ -919,8 +913,9 @@ class HpxGeom(MapGeom):
 
     @property
     def order(self):
-        """ORDER in each band (NSIDE = 2**ORDER).  Set to -1 for bands with
-        NSIDE that is not a power of 2.
+        """ORDER in each band (``NSIDE = 2 ** ORDER``).
+
+        Set to -1 for bands with NSIDE that is not a power of 2.
         """
         return self._order
 
@@ -1007,8 +1002,9 @@ class HpxGeom(MapGeom):
         return self.get_idx()
 
     def to_ud_graded(self, order):
-        """Upgrade or downgrade the resolution of this geometry to the given
-        order.  This method does not preserve the geometry footprint.
+        """Upgrade or downgrade the resolution to the given order.
+
+        This method does not preserve the geometry footprint.
 
         Returns
         -------
@@ -1029,8 +1025,7 @@ class HpxGeom(MapGeom):
         )
 
     def to_swapped(self):
-        """Make a copy of this geometry with a swapped ORDERING.  (NEST->RING
-        or vice versa)
+        """Geometry copy with swapped ORDERING (NEST->RING or vice versa).
 
         Returns
         -------
@@ -1411,7 +1406,7 @@ class HpxGeom(MapGeom):
         return cls.from_header(hdu.header, hdu_bands=hdu_bands, pix=pix)
 
     def make_header(self, **kwargs):
-        """"Build and return FITS header for this HEALPIX map."""
+        """Build and return FITS header for this HEALPIX map."""
         header = fits.Header()
         conv = kwargs.get("conv", HPX_FITS_CONVENTIONS[self.conv])
 
@@ -1596,7 +1591,7 @@ class HpxGeom(MapGeom):
         )
 
     def get_idx(self, idx=None, local=False, flat=False):
-        if idx is not None and np.any(np.array(idx) >= np.array(self._shape)):
+        if idx is not None and np.any(np.array(idx) >= np.array(self.shape_axes)):
             raise ValueError("Image index out of range: {!r}".format(idx))
 
         # Regular all- and partial-sky maps
@@ -1615,11 +1610,11 @@ class HpxGeom(MapGeom):
 
             shape = (np.max(self.npix),)
             if idx is None:
-                shape = shape + self.shape
+                shape = shape + self.shape_axes
             else:
                 shape = shape + (1,) * len(self.axes)
             pix = [np.full(shape, -1, dtype=int) for i in range(1 + len(self.axes))]
-            for idx_img in np.ndindex(self.shape):
+            for idx_img in np.ndindex(self.shape_axes):
 
                 if idx is not None and idx_img != idx:
                     continue
@@ -1640,7 +1635,7 @@ class HpxGeom(MapGeom):
 
             if idx is not None:
                 npix_sum = np.concatenate(([0], np.cumsum(self._npix)))
-                idx_ravel = np.ravel_multi_index(idx, self._shape)
+                idx_ravel = np.ravel_multi_index(idx, self.shape_axes)
                 s = slice(npix_sum[idx_ravel], npix_sum[idx_ravel + 1])
             else:
                 s = slice(None)
@@ -1648,12 +1643,12 @@ class HpxGeom(MapGeom):
 
             shape = (np.max(self.npix),)
             if idx is None:
-                shape = shape + self.shape
+                shape = shape + self.shape_axes
             else:
                 shape = shape + (1,) * len(self.axes)
             pix = [np.full(shape, -1, dtype=int) for _ in range(1 + len(self.axes))]
 
-            for idx_img in np.ndindex(self.shape):
+            for idx_img in np.ndindex(self.shape_axes):
 
                 if idx is not None and idx_img != idx:
                     continue
@@ -1682,7 +1677,7 @@ class HpxGeom(MapGeom):
             pix = self.global_to_local(pix)
 
         if flat:
-            pix = tuple([p[p != -1] for p in pix])
+            pix = tuple([p[p != INVALID_INDEX.int] for p in pix])
 
         return pix
 
@@ -1698,10 +1693,10 @@ class HpxGeom(MapGeom):
 
     def contains(self, coords):
         idx = self.coord_to_idx(coords)
-        return np.all(np.stack([t != -1 for t in idx]), axis=0)
+        return np.all(np.stack([t != INVALID_INDEX.int for t in idx]), axis=0)
 
     def get_skydirs(self):
-        """Get the sky coordinates of all the pixels in this geometry. """
+        """Get the sky coordinates of all the pixels in this geometry."""
         coords = self.get_coord()
         frame = "galactic" if self.coordsys == "GAL" else "icrs"
         return SkyCoord(coords[0], coords[1], unit="deg", frame=frame)
@@ -1732,7 +1727,6 @@ class HpxGeom(MapGeom):
         return str_
 
     def __eq__(self, other):
-        """Test equality between two `~gammapy.maps.HpxGeom`"""
         if not isinstance(other, self.__class__):
             return NotImplemented
 
@@ -1760,7 +1754,7 @@ class HpxGeom(MapGeom):
         return not self.__eq__(other)
 
 
-class HpxToWcsMapping(object):
+class HpxToWcsMapping:
     """Stores the indices need to convert from HEALPIX to WCS.
 
     Parameters
@@ -1782,45 +1776,42 @@ class HpxToWcsMapping(object):
 
     @property
     def hpx(self):
-        """The HEALPIX projection"""
+        """HEALPIX projection."""
         return self._hpx
 
     @property
     def wcs(self):
-        """The WCS projection"""
+        """WCS projection."""
         return self._wcs
 
     @property
     def ipix(self):
-        """An array(nx,ny) of the global HEALPIX pixel indices for each WCS pixel"""
+        """An array(nx,ny) of the global HEALPIX pixel indices for each WCS pixel."""
         return self._ipix
 
     @property
     def mult_val(self):
-        """An array(nx,ny) of 1/number of WCS pixels pointing at each HEALPIX pixel"""
+        """An array(nx,ny) of 1/number of WCS pixels pointing at each HEALPIX pixel."""
         return self._mult_val
 
     @property
     def npix(self):
-        """A tuple(nx,ny) of the shape of the WCS grid"""
+        """A tuple(nx,ny) of the shape of the WCS grid."""
         return self._npix
 
     @property
     def lmap(self):
-        """An array(nx,ny) giving the mapping of the local HEALPIX pixel
-        indices for each WCS pixel"""
+        """Array ``(nx, ny)`` mapping local HEALPIX pixel indices for each WCS pixel."""
         return self._lmap
 
     @property
     def valid(self):
-        """An array(nx,ny) of bools giving if each WCS pixel in inside the
-        HEALPIX region"""
+        """Array ``(nx, ny)`` of bool: which WCS pixel in inside the HEALPIX region."""
         return self._valid
 
     @classmethod
     def create(cls, hpx, wcs):
-        """Create an object that maps pixels from HEALPix geometry ``hpx`` to
-        WCS geometry ``wcs``.
+        """Create HEALPix to WCS geometry pixel mapping.
 
         Parameters
         ----------
