@@ -1,11 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
 from astropy.io import fits
 from astropy.units import Quantity
 from ..utils.units import unit_from_fits_image_hdu
 from .geom import MapCoord, pix_tuple_to_idx
-from .utils import interp_to_order
+from .utils import interp_to_order, INVALID_INDEX
 from .hpxmap import HpxMap
 from .hpx import HpxGeom, HpxToWcsMapping, nside_to_order
 
@@ -13,8 +12,7 @@ __all__ = ["HpxNDMap"]
 
 
 class HpxNDMap(HpxMap):
-    """Representation of a N+2D map using HEALPix with two spatial
-    dimensions and N non-spatial dimensions.
+    """HEALPix map with any number of non-spatial dimensions.
 
     This class uses a N+1D numpy array to represent the sequence of
     HEALPix image planes.  Following the convention of WCS-based maps
@@ -40,7 +38,7 @@ class HpxNDMap(HpxMap):
         if data is None:
             data = self._make_default_data(geom, data_shape, dtype)
 
-        super(HpxNDMap, self).__init__(geom, data, meta, unit)
+        super().__init__(geom, data, meta, unit)
         self._wcs2d = None
         self._hpx2wcs = None
 
@@ -174,7 +172,7 @@ class HpxNDMap(HpxMap):
             wcs = hpx2wcs.wcs.to_image()
         else:
             hpx_data = self.data
-            wcs_shape = tuple([t.flat[0] for t in hpx2wcs.npix]) + self.geom.shape
+            wcs_shape = tuple([t.flat[0] for t in hpx2wcs.npix]) + self.geom.shape_axes
             wcs_data = np.zeros(wcs_shape).T
             wcs = hpx2wcs.wcs.to_cube(self.geom.axes)
 
@@ -271,7 +269,6 @@ class HpxNDMap(HpxMap):
     def interp_by_coord(self, coords, interp=1):
         # inherited docstring
         coords = MapCoord.create(coords, coordsys=self.geom.coordsys)
-        coords = coords.match_axes_units(self.geom)
 
         order = interp_to_order(interp)
         if order == 1:
@@ -309,7 +306,7 @@ class HpxNDMap(HpxMap):
 
         pix, wts = hp.get_interp_weights(nside, theta, phi, nest=self.geom.nest)
         wts[:, m] = 0
-        pix[:, m] = -1
+        pix[:, m] = INVALID_INDEX.int
 
         if not self.geom.is_regular:
             pix_local = [self.geom.global_to_local([pix] + list(idxs))[0]]
@@ -317,7 +314,7 @@ class HpxNDMap(HpxMap):
             pix_local = [self.geom[pix]]
 
         # If a pixel lies outside of the geometry set its index to the center pixel
-        m = pix_local[0] == -1
+        m = pix_local[0] == INVALID_INDEX.int
         if m.any():
             coords_ctr = [coords.lon, coords.lat]
             coords_ctr += [ax.pix_to_coord(t) for ax, t in zip(self.geom.axes, idxs)]
@@ -346,17 +343,19 @@ class HpxNDMap(HpxMap):
                 idx = np.clip(idx, 0, len(ax.center) - 2)
 
                 w = ax.center[idx + 1] - ax.center[idx]
+                c = Quantity(coords[ax.name], ax.center.unit, copy=False).value
+
                 if i & (1 << j):
-                    wt *= (coords[ax.name] - ax.center[idx]) / w
+                    wt *= (c - ax.center[idx].value) / w.value
                     pix_i += [idx + 1]
                 else:
-                    wt *= 1.0 - (coords[ax.name] - ax.center[idx]) / w
+                    wt *= 1.0 - (c - ax.center[idx].value) / w.value
                     pix_i += [idx]
 
             if not self.geom.is_regular:
                 pix, wts = self._get_interp_weights(coords, pix_i)
 
-            wts[pix[0] == -1] = 0
+            wts[pix[0] == INVALID_INDEX.int] = 0
             wt[~np.isfinite(wt)] = 0
             val += np.nansum(wts * wt * self.data.T[tuple(pix[:1] + pix_i)], axis=0)
 
@@ -364,7 +363,7 @@ class HpxNDMap(HpxMap):
 
     def fill_by_idx(self, idx, weights=None):
         idx = pix_tuple_to_idx(idx)
-        msk = np.all(np.stack([t != -1 for t in idx]), axis=0)
+        msk = np.all(np.stack([t != INVALID_INDEX.int for t in idx]), axis=0)
         if weights is not None:
             weights = weights[msk]
         idx = [t[msk] for t in idx]
