@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
 from astropy.io import fits
 from .sparse import SparseArray
@@ -11,8 +10,7 @@ __all__ = ["HpxSparseMap"]
 
 
 class HpxSparseMap(HpxMap):
-    """Representation of a N+2D map using HEALPIX with two spatial
-    dimensions and N non-spatial dimensions.
+    """HEALPix sparse map with any number of non-spatial dimensions.
 
     This class uses a sparse matrix for HEALPix pixel values.
 
@@ -35,7 +33,7 @@ class HpxSparseMap(HpxMap):
         elif isinstance(data, np.ndarray):
             data = SparseArray.from_array(data)
 
-        super(HpxSparseMap, self).__init__(geom, data, meta, unit)
+        super().__init__(geom, data, meta, unit)
 
     @classmethod
     def from_hdu(cls, hdu, hdu_bands=None):
@@ -151,12 +149,6 @@ class HpxSparseMap(HpxMap):
     def iter_by_image(self):
         raise NotImplementedError
 
-    def iter_by_pix(self):
-        raise NotImplementedError
-
-    def iter_by_coord(self):
-        raise NotImplementedError
-
     def sum_over_axes(self):
         raise NotImplementedError
 
