@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
 import astropy.units as u
 from scipy.ndimage import map_coordinates
@@ -9,10 +8,7 @@ __all__ = ["reproject_car_to_hpx", "reproject_car_to_wcs"]
 
 
 def _get_input_pix_celestial(wcs_in, wcs_out, shape_out):
-    """
-    Get the pixel coordinates of the pixels in an array of shape ``shape_out``
-    in the input WCS.
-    """
+    """Get the pixel coordinates of the pixels in an array of shape ``shape_out`` in the input WCS."""
     from reproject.wcs_utils import convert_world_coordinates
 
     # TODO: for now assuming that coordinates are spherical, not
