@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 from collections import OrderedDict
 import numpy as np
@@ -128,7 +127,7 @@ def test_map_slice_by_idx(binsz, width, map_type, skydir, axes, unit):
 
     # Test none slicing
     sliced = m.slice_by_idx({})
-    assert_equal(m.geom.shape, sliced.geom.shape)
+    assert_equal(m.geom.shape_axes, sliced.geom.shape_axes)
 
     slices = {"energy": slice(0, 1), "time": slice(0, 2)}
     sliced = m.slice_by_idx(slices)
