@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose, assert_equal
@@ -7,6 +6,7 @@ from astropy.io import fits
 from astropy.coordinates import SkyCoord
 from astropy.convolution import Gaussian2DKernel
 import astropy.units as u
+from regions import CircleSkyRegion
 from ...utils.testing import requires_dependency, requires_data, mpl_plot_check
 from ...cube import PSFKernel
 from ...irf import EnergyDependentMultiGaussPSF
@@ -159,6 +159,18 @@ def test_wcsndmap_set_get_by_pix(npix, binsz, coordsys, proj, skydir, axes):
     assert_allclose(coords[0], m.get_by_pix(pix))
 
 
+def test_get_by_coord_bool_int():
+    mask = WcsNDMap.create(width=2, dtype="bool")
+    coords = {"lon": [0, 3], "lat": [0, 3]}
+    vals = mask.get_by_coord(coords)
+    assert_allclose(vals, [0, np.nan])
+
+    mask = WcsNDMap.create(width=2, dtype="int")
+    coords = {"lon": [0, 3], "lat": [0, 3]}
+    vals = mask.get_by_coord(coords)
+    assert_allclose(vals, [0, np.nan])
+
+
 @pytest.mark.parametrize(
     ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
 )
@@ -307,22 +319,6 @@ def test_wcsndmap_interp_by_coord_fill_value():
     assert_allclose(m.interp_by_coord((99, 0)), 42)
 
 
-@pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
-)
-def test_wcsndmap_iter(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
-    )
-    m = WcsNDMap(geom)
-    coords = m.geom.get_coord()
-    m.fill_by_coord(coords, coords[0])
-    for vals, pix in m.iter_by_pix(buffersize=100):
-        assert_allclose(vals, m.get_by_pix(pix))
-    for vals, coords in m.iter_by_coord(buffersize=100):
-        assert_allclose(vals, m.get_by_coord(coords))
-
-
 @pytest.mark.parametrize(
     ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
 )
@@ -340,30 +336,33 @@ def test_wcsndmap_sum_over_axes(npix, binsz, coordsys, proj, skydir, axes, keepd
         assert_allclose(np.nansum(m.data), np.nansum(msum.data))
 
 
-@pytest.mark.parametrize(
-    ("npix", "binsz", "coordsys", "proj", "skydir", "axes"), wcs_test_geoms
-)
-def test_wcsndmap_reproject(npix, binsz, coordsys, proj, skydir, axes):
-    geom = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, skydir=skydir, coordsys=coordsys, axes=axes
-    )
-    m = WcsNDMap(geom, unit="m2")
+def test_wcsndmap_reproject():
+    skydir = SkyCoord(110.0, 75.0, unit="deg", frame="icrs")
+    geom = WcsGeom.create(npix=10, binsz=1.0, coordsys="GAL", proj="AIT", skydir=skydir)
+    geom_new = geom.downsample(2)
 
-    if geom.projection == "AIT" and geom.is_allsky:
-        pytest.xfail("Bug in reproject version <= 0.3.1")
+    data = np.arange(np.prod(geom.data_shape)).reshape(geom.data_shape)
+    m = WcsNDMap(data=data, geom=geom, unit="m2")
 
-    if geom.ndim > 3 or geom.npix[0].size > 1:
-        pytest.xfail("> 3 dimensions or multi-resolution geometries not supported")
+    m_reprojected = m.reproject(geom_new, order=1)
+    assert m.unit == m_reprojected.unit
 
-    geom0 = WcsGeom.create(
-        npix=npix, binsz=binsz, proj=proj, skydir=skydir, coordsys=coordsys, axes=axes
-    )
-    m0 = m.reproject(geom0, order=1)
+    assert_allclose(m_reprojected.data[0, 0], 5.5)
+    assert_allclose(m_reprojected.data[4, 4], 93.5)
 
-    assert_allclose(m.data, m0.data)
-    assert m0.unit == m.unit
+    energy_axis = MapAxis.from_bounds(0.1, 10, 2, name="energy", interp="log")
+    geom_3d = geom.to_cube([energy_axis])
 
-    # TODO : Reproject to a different spatial geometry
+    data = np.arange(np.prod(geom_3d.data_shape)).reshape(geom_3d.data_shape)
+    m = WcsNDMap(data=data, geom=geom_3d, unit="m2")
+
+    m_reprojected = m.reproject(geom_new, order=1)
+    assert m.unit == m_reprojected.unit
+
+    assert_allclose(m_reprojected.data[0, 0, 0], 5.5)
+    assert_allclose(m_reprojected.data[1, 4, 4], 193.5)
+
+    assert m_reprojected.geom.axes[0].name == "energy"
 
 
 @requires_dependency("healpy")
@@ -440,11 +439,32 @@ def test_wcsndmap_upsample(npix, binsz, coordsys, proj, skydir, axes):
         npix=npix, binsz=binsz, proj=proj, coordsys=coordsys, axes=axes
     )
     m = WcsNDMap(geom, unit="m2")
-    m2 = m.upsample(2, order=0, preserve_counts=True)
+    m2 = m.upsample(2, preserve_counts=True)
     assert_allclose(np.nansum(m.data), np.nansum(m2.data))
     assert m.unit == m2.unit
 
 
+def test_wcsndmap_upsample_axis():
+    axis = MapAxis.from_nodes([1, 2, 3, 4], name="test")
+    geom = WcsGeom.create(npix=(4, 4), axes=[axis])
+    m = WcsNDMap(geom, unit="m2")
+    m.data += 1
+
+    m2 = m.upsample(2, preserve_counts=True, axis="test")
+    assert m2.data.shape == (8, 4, 4)
+    assert_allclose(m.data.sum(), m2.data.sum())
+
+
+def test_wcsndmap_downsample_axis():
+    axis = MapAxis.from_nodes([1, 2, 3, 4], name="test")
+    geom = WcsGeom.create(npix=(4, 4), axes=[axis])
+    m = WcsNDMap(geom, unit="m2")
+    m.data += 1
+
+    m2 = m.downsample(2, preserve_counts=True, axis="test")
+    assert m2.data.shape == (2, 4, 4)
+
+
 def test_coadd_unit():
     geom = WcsGeom.create(npix=(10, 10), binsz=1, proj="CAR", coordsys="GAL")
     m1 = WcsNDMap(geom, data=np.ones((10, 10)), unit="m2")
@@ -468,6 +488,7 @@ def test_smooth(kernel):
     smoothed = m.smooth(0.2 * u.deg, kernel)
     actual = smoothed.data.sum()
     assert_allclose(actual, desired)
+    assert smoothed.data.dtype == float
 
 
 @pytest.mark.parametrize("mode", ["partial", "strict", "trim"])
@@ -480,8 +501,8 @@ def test_make_cutout(mode):
     cutout = m.cutout(position=pos, width=(2.0, 3.0) * u.deg, mode=mode)
     actual = cutout.data.sum()
     assert_allclose(actual, 36.0)
-    assert_allclose(cutout.geom.shape, m.geom.shape)
-    assert_allclose(cutout.geom.width, [[2.0], [3.0]])
+    assert_allclose(cutout.geom.shape_axes, m.geom.shape_axes)
+    assert_allclose(cutout.geom.width.to_value("deg"), [[2.0], [3.0]])
 
 
 def test_convolve_vs_smooth():
@@ -500,7 +521,7 @@ def test_convolve_vs_smooth():
     assert_allclose(actual.data, desired.data, rtol=1e-3)
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_convolve_nd():
     energy_axis = MapAxis.from_edges(
         np.logspace(-1.0, 1.0, 4), unit="TeV", name="energy"
@@ -531,9 +552,9 @@ def test_convolve_pixel_scale_error():
 
     kernel = PSFKernel.from_gauss(kgeom, sigma=0.1 * u.deg, max_radius=1.5 * u.deg)
 
-    with pytest.raises(ValueError) as err:
+    with pytest.raises(ValueError) as excinfo:
         m.convolve(kernel)
-        assert "Kernel shape larger" in str(err.value)
+    assert "Pixel size of kernel and map not compatible." == str(excinfo.value)
 
 
 @requires_dependency("matplotlib")
@@ -548,3 +569,23 @@ def test_plot_allsky():
     m = WcsNDMap.create(binsz=10 * u.deg)
     with mpl_plot_check():
         m.plot()
+
+
+def test_get_spectrum():
+    axis = MapAxis.from_bounds(1, 10, nbin=3, unit="TeV", name="energy")
+
+    geom = WcsGeom.create(
+        skydir=(0, 0), width=(2.5, 2.5), binsz=0.5, axes=[axis], coordsys="GAL"
+    )
+
+    m = Map.from_geom(geom)
+    m.data += 1
+
+    center = SkyCoord(0, 0, frame="galactic", unit="deg")
+    region = CircleSkyRegion(center=center, radius=1 * u.deg)
+
+    spec = m.get_spectrum(region=region)
+    assert_allclose(spec.data, [13.0, 13.0, 13.0])
+
+    spec = m.get_spectrum(region=region, func=np.mean)
+    assert_allclose(spec.data, [1.0, 1.0, 1.0])
