@@ -1,9 +1,41 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
+import numpy as np
 from astropy.io import fits
 from ..utils.random import get_random_state
 
 
+class InvalidValue:
+    """Class to define placeholder for invalid array values."""
+
+    float = np.nan
+    int = np.nan
+    bool = np.nan
+
+    def __getitem__(self, dtype):
+        if np.issubdtype(dtype, np.integer):
+            return self.int
+        elif np.issubdtype(dtype, np.floating):
+            return self.float
+        elif np.issubdtype(dtype, np.dtype(bool).type):
+            return self.bool
+        else:
+            raise ValueError(
+                "No invalid value placeholder defined for {}".format(dtype)
+            )
+
+
+class InvalidIndex:
+    """Class to define placeholder for invalid array indices."""
+
+    float = np.nan
+    int = -1
+    bool = False
+
+
+INVALID_VALUE = InvalidValue()
+INVALID_INDEX = InvalidIndex()
+
+
 def fill_poisson(map_in, mu, random_state="random-seed"):
     """Fill a map object with a poisson random variable.
 
@@ -55,24 +87,6 @@ def interp_to_order(interp):
     return order_map.get(interp, None)
 
 
-def unpack_seq(seq, n=1):
-    """Utility to unpack the first N values of a tuple or list.  Remaining
-    values are put into a single list which is the last element of the
-    return value.  This partially simulates the extended unpacking
-    functionality available in Python 3.
-
-    Parameters
-    ----------
-    seq : list or tuple
-        Input sequence to be unpacked.
-    n : int
-        Number of elements of ``seq`` to unpack.  Remaining elements
-        are put into a single tuple.
-    """
-    for row in seq:
-        yield [e for e in row[:n]] + [row[n:]]
-
-
 def find_bands_hdu(hdu_list, hdu):
     """Discover the extension name of the BANDS HDU.
 
@@ -136,3 +150,12 @@ def find_bintable_hdu(hdulist):
             return hdu
 
     raise AttributeError("No BinTable HDU found.")
+
+
+def edges_from_lo_hi(edges_lo, edges_hi):
+    edges = edges_lo.copy()
+    try:
+        edges = edges.insert(len(edges), edges_hi[-1])
+    except AttributeError:
+        edges = np.insert(edges, len(edges), edges_hi[-1])
+    return edges
