@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import logging
 import numpy as np
 from astropy.io import fits
@@ -15,7 +14,7 @@ from ..utils.units import unit_from_fits_image_hdu
 from ..utils.interpolation import ScaledRegularGridInterpolator
 from .geom import pix_tuple_to_idx
 from .wcs import _check_width
-from .utils import interp_to_order
+from .utils import interp_to_order, INVALID_INDEX
 from .wcsmap import WcsGeom, WcsMap
 from .reproject import reproject_car_to_hpx, reproject_car_to_wcs
 
@@ -26,8 +25,7 @@ log = logging.getLogger(__name__)
 
 
 class WcsNDMap(WcsMap):
-    """Representation of a N+2D map using WCS with two spatial dimensions
-    and N non-spatial dimensions.
+    """HEALPix map with any number of non-spatial dimensions.
 
     This class uses an ND numpy array to store map values. For maps with
     non-spatial dimensions and variable pixel size it will allocate an
@@ -55,14 +53,14 @@ class WcsNDMap(WcsMap):
         if data is None:
             data = self._make_default_data(geom, data_shape, dtype)
 
-        super(WcsNDMap, self).__init__(geom, data, meta, unit)
+        super().__init__(geom, data, meta, unit)
 
     @staticmethod
     def _make_default_data(geom, shape_np, dtype):
         # Check whether corners of each image plane are valid
         coords = []
         if not geom.is_regular:
-            for idx in np.ndindex(geom.shape):
+            for idx in np.ndindex(geom.shape_axes):
                 pix = (
                     np.array([0.0, float(geom.npix[0][idx] - 1)]),
                     np.array([0.0, float(geom.npix[1][idx] - 1)]),
@@ -83,12 +81,12 @@ class WcsNDMap(WcsMap):
                 data = np.zeros(shape_np, dtype=dtype)
             else:
                 data = np.full(shape_np, np.nan, dtype=dtype)
-                for idx in np.ndindex(geom.shape):
+                for idx in np.ndindex(geom.shape_axes):
                     data[idx, slice(geom.npix[0][idx]), slice(geom.npix[1][idx])] = 0.0
         else:
             data = np.full(shape_np, np.nan, dtype=dtype)
             idx = geom.get_idx()
-            m = np.all(np.stack([t != -1 for t in idx]), axis=0)
+            m = np.all(np.stack([t != INVALID_INDEX.int for t in idx]), axis=0)
             data[m] = 0.0
 
         return data
@@ -212,7 +210,7 @@ class WcsNDMap(WcsMap):
 
     def fill_by_idx(self, idx, weights=None):
         idx = pix_tuple_to_idx(idx)
-        msk = np.all(np.stack([t != -1 for t in idx]), axis=0)
+        msk = np.all(np.stack([t != INVALID_INDEX.int for t in idx]), axis=0)
         idx = [t[msk] for t in idx]
 
         if weights is not None:
@@ -324,9 +322,10 @@ class WcsNDMap(WcsMap):
             return self._pad_coadd(geom, pad_width, mode, cval, order)
 
     def _pad_np(self, geom, pad_width, mode, cval):
-        """Pad a map with `~np.pad`.  This method only works for regular
-        geometries but should be more efficient when working with
-        large maps.
+        """Pad a map using ``numpy.pad``.
+
+        This method only works for regular geometries but should be more
+        efficient when working with large maps.
         """
         kwargs = {}
         if mode == "constant":
@@ -337,8 +336,7 @@ class WcsNDMap(WcsMap):
         return self._init_copy(geom=geom, data=data)
 
     def _pad_coadd(self, geom, pad_width, mode, cval, order):
-        """Pad a map manually by coadding the original map with the new
-        map."""
+        """Pad a map manually by coadding the original map with the new map."""
         idx_in = self.geom.get_idx(flat=True)
         idx_in = tuple([t + w for t, w in zip(idx_in, pad_width)])[::-1]
         idx_out = geom.get_idx(flat=True)[::-1]
@@ -382,25 +380,41 @@ class WcsNDMap(WcsMap):
 
         return map_out
 
-    def upsample(self, factor, order=0, preserve_counts=True):
-        geom = self.geom.upsample(factor)
+    def upsample(self, factor, order=0, preserve_counts=True, axis=None):
+        geom = self.geom.upsample(factor, axis=axis)
         idx = geom.get_idx()
-        pix = (
-            (idx[0] - 0.5 * (factor - 1)) / factor,
-            (idx[1] - 0.5 * (factor - 1)) / factor,
-        ) + idx[2:]
-        data = map_coordinates(self.data.T, pix, order=order, mode="nearest")
+
+        if axis is None:
+            pix = (
+                (idx[0] - 0.5 * (factor - 1)) / factor,
+                (idx[1] - 0.5 * (factor - 1)) / factor,
+            ) + idx[2:]
+        else:
+            pix = list(idx)
+            idx_ax = self.geom.get_axis_index_by_name(axis)
+            pix[idx_ax] = (pix[idx_ax] - 0.5 * (factor - 1)) / factor
+
+        data = map_coordinates(self.data.T, tuple(pix), order=order, mode="nearest")
+
         if preserve_counts:
-            data /= factor ** 2
+            if axis is None:
+                data /= factor ** 2
+            else:
+                data /= factor
 
         return self._init_copy(geom=geom, data=data)
 
-    def downsample(self, factor, preserve_counts=True):
-        geom = self.geom.downsample(factor)
-        block_size = (factor, factor) + (1,) * len(self.geom.axes)
-        data = block_reduce(self.data, block_size[::-1], np.nansum)
-        if not preserve_counts:
-            data /= factor ** 2
+    def downsample(self, factor, preserve_counts=True, axis=None):
+        geom = self.geom.downsample(factor, axis=axis)
+        if axis is None:
+            block_size = (factor, factor) + (1,) * len(self.geom.axes)
+        else:
+            block_size = [1] * self.data.ndim
+            idx = self.geom.get_axis_index_by_name(axis)
+            block_size[-(idx + 1)] = factor
+
+        func = np.nansum if preserve_counts else np.nanmean
+        data = block_reduce(self.data, tuple(block_size[::-1]), func=func)
 
         return self._init_copy(geom=geom, data=data)
 
@@ -453,6 +467,7 @@ class WcsNDMap(WcsMap):
         kwargs.setdefault("interpolation", "nearest")
         kwargs.setdefault("origin", "lower")
         kwargs.setdefault("cmap", "afmhot")
+
         norm = simple_norm(data[np.isfinite(data)], stretch)
         kwargs.setdefault("norm", norm)
 
@@ -506,9 +521,9 @@ class WcsNDMap(WcsMap):
         return ax
 
     def smooth(self, width, kernel="gauss", **kwargs):
-        """
-        Smooth the image (works on a 2D image and returns a copy).
+        """Smooth the map.
 
+        Iterates over 2D image planes, processing one at a time.
 
         Parameters
         ----------
@@ -553,6 +568,41 @@ class WcsNDMap(WcsMap):
 
         return self._init_copy(data=smoothed_data)
 
+    def get_spectrum(self, region=None, func=np.nansum):
+        """Extract spectrum in a given region.
+
+        The spectrum can be computed by summing (or, more generally, applying `func`)
+        along the spatial axes in each energy bin. This occurs only inside the `region`,
+        which by default is assumed to be the whole spatial extension of the map.
+
+        Parameters
+        ----------
+        region: `~regions.Region`
+             Region (pixel or sky regions accepted).
+        func : `~numpy.ufunc`
+            Function to reduce the data.
+
+        Returns
+        -------
+        spectrum : `CountsSpectrum`
+            Spectrum in the given region.
+        """
+        from ..spectrum import CountsSpectrum
+
+        energy_axis = self.geom.get_axis_by_name("energy")
+
+        if region:
+            mask = self.geom.region_mask([region])
+            data = self.data[mask].reshape(energy_axis.nbin, -1)
+            data = func(data, axis=1)
+        else:
+            data = func(self.data, axis=(1, 2))
+
+        edges = energy_axis.edges
+        return CountsSpectrum(
+            data=data, energy_lo=edges[:-1], energy_hi=edges[1:], unit=self.unit
+        )
+
     def convolve(self, kernel, use_fft=True, **kwargs):
         """
         Convolve map with a kernel.
