@@ -1,12 +1,11 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 from numpy.testing import assert_allclose
 from ...utils.testing import requires_data, run_cli, assert_wcs_allclose
 from ...maps import Map
 from ..main import cli
 
 
-@requires_data("gammapy-data")
+@requires_data()
 def test_bin_image_main(tmpdir):
     """Run ``gammapy-bin-image`` and compare result to ``ctskymap``.
     """
