@@ -6,7 +6,7 @@ import astropy.units as u
 from regions import CircleSkyRegion
 from ..utils.scripts import make_path
 from ..irf import PSF3D, apply_containment_fraction, compute_energy_thresholds
-from .core import PHACountsSpectrum
+from .core import CountsSpectrum
 from .dataset import SpectrumDatasetOnOff
 
 __all__ = ["SpectrumExtraction"]
@@ -91,7 +91,7 @@ class SpectrumExtraction:
             self.spectrum_observations.append(self.process(obs, bkg))
 
     def _alpha_ok(self, bkg):
-        """Check if observation fulfills alpha criterion"""
+        """Check if observation fulfills alpha criterion."""
         condition = bkg.a_off == 0 or bkg.a_on / bkg.a_off > self.max_alpha
         if condition:
             msg = "Skipping because {} / {} > {}"
@@ -118,7 +118,7 @@ class SpectrumExtraction:
         log.info("Process observation\n {}".format(observation))
         self.make_empty_vectors(observation, bkg)
         self.extract_counts(bkg)
-        self.extract_irfs(observation)
+        self.extract_irfs(observation, bkg)
 
         if self.containment_correction:
             self.apply_containment_correction(observation, bkg)
@@ -130,13 +130,20 @@ class SpectrumExtraction:
             aeff=self._aeff,
             counts_off=self._off_vector,
             edisp=self._edisp,
-            livetime=self._on_vector.livetime,
+            livetime=observation.observation_live_time_duration,
+            acceptance=1,
+            acceptance_off=bkg.a_off,
+            obs_id=observation.obs_id,
+            gti=observation.gti,
         )
 
         if self.use_recommended_erange:
             try:
-                spectrum_observation.hi_threshold = observation.aeff.high_threshold
-                spectrum_observation.lo_threshold = observation.aeff.low_threshold
+                e_max = observation.aeff.high_threshold
+                e_min = observation.aeff.low_threshold
+                spectrum_observation.mask_safe = spectrum_observation.counts.energy_mask(
+                    emin=e_min, emax=e_max
+                )
             except KeyError:
                 log.warning("No thresholds defined for obs {}".format(observation))
 
@@ -159,18 +166,11 @@ class SpectrumExtraction:
         offset = observation.pointing_radec.separation(bkg.on_region.center)
         log.info("Offset : {}\n".format(offset))
 
-        self._on_vector = PHACountsSpectrum(
-            energy_lo=self.e_reco[:-1],
-            energy_hi=self.e_reco[1:],
-            backscal=bkg.a_on,
-            offset=offset,
-            livetime=observation.observation_live_time_duration,
-            obs_id=observation.obs_id,
+        self._on_vector = CountsSpectrum(
+            energy_lo=self.e_reco[:-1], energy_hi=self.e_reco[1:]
         )
 
         self._off_vector = self._on_vector.copy()
-        self._off_vector.is_bkg = True
-        self._off_vector.backscal = bkg.a_off
 
     def extract_counts(self, bkg):
         """Fill on and off vector for one observation.
@@ -184,7 +184,7 @@ class SpectrumExtraction:
         self._on_vector.fill(bkg.on_events)
         self._off_vector.fill(bkg.off_events)
 
-    def extract_irfs(self, observation):
+    def extract_irfs(self, observation, bkg):
         """Extract IRFs.
 
         Parameters
@@ -193,7 +193,7 @@ class SpectrumExtraction:
             Observation
         """
         log.info("Extract IRFs")
-        offset = self._on_vector.offset
+        offset = observation.pointing_radec.separation(bkg.on_region.center)
         self._aeff = observation.aeff.to_effective_area_table(
             offset, energy=self.e_true
         )
@@ -220,7 +220,7 @@ class SpectrumExtraction:
         log.info("Apply containment correction")
         # First need psf
         angles = np.linspace(0.0, 1.5, 150) * u.deg
-        offset = self._on_vector.offset
+        offset = observation.pointing_radec.separation(bkg.on_region.center)
         if isinstance(observation.psf, PSF3D):
             psf = observation.psf.to_energy_dependent_table_psf(theta=offset)
         else:
@@ -232,7 +232,7 @@ class SpectrumExtraction:
         self.containment = new_aeff.data.data.value / self._aeff.data.data.value
         self._aeff = new_aeff
 
-    def compute_energy_threshold(self, reset=False, **kwargs):
+    def compute_energy_threshold(self, **kwargs):
         """Compute and set the safe energy threshold for all observations.
 
         See `~gammapy.irf.compute_energy_thresholds` for full
