@@ -10,7 +10,6 @@ from ..utils.table import table_standardise_units_copy, table_from_row_data
 from ..utils.interpolation import interpolate_likelihood_profile
 from ..utils.fitting import Dataset, Datasets, Fit
 from .models import PowerLaw, ScaleModel
-from .powerlaw import power_law_integral_flux
 from .dataset import SpectrumDatasetOnOff
 
 __all__ = ["FluxPoints", "FluxPointsEstimator", "FluxPointsDataset"]
@@ -314,7 +313,7 @@ class FluxPoints:
     def to_sed_type(self, sed_type, method="log_center", model=None, pwl_approx=False):
         """Convert to a different SED type (return new `FluxPoints`).
 
-        See: http://adsabs.harvard.edu/abs/1995NIMPA.355..541L for details
+        See: https://ui.adsabs.harvard.edu/abs/1995NIMPA.355..541L for details
         on the `'lafferty'` method.
 
         Parameters
@@ -408,8 +407,12 @@ class FluxPoints:
 
         if pwl_approx:
             index = model.spectral_index(e_ref)
-            flux_model = power_law_integral_flux(
-                f=dnde_model, g=index, e=e_ref, e1=e_min, e2=e_max
+            flux_model = PowerLaw.evaluate_integral(
+                emin=e_min,
+                emax=e_max,
+                index=index,
+                reference=e_ref,
+                amplitude=dnde_model,
             )
         else:
             flux_model = model.integral(e_min, e_max, intervals=True)
@@ -1019,14 +1022,13 @@ class FluxPointsEstimator:
         return {"norm_err": norm_err}
 
     def estimate_counts(self):
-        """Estimate counts for the flux point
+        """Estimate counts for the flux point.
 
         Returns
         -------
         result : dict
             Dict with an array with one entry per dataset with counts for the flux point.
         """
-
         counts = []
 
         for dataset in self.datasets.datasets:
@@ -1034,10 +1036,7 @@ class FluxPointsEstimator:
             if dataset.mask_safe is not None:
                 mask &= dataset.mask_safe
 
-            if isinstance(dataset, SpectrumDatasetOnOff):
-                counts.append(dataset.counts.data.data[mask].sum())
-            else:
-                counts.append(dataset.counts.data[mask].sum())
+            counts.append(dataset.counts.data[mask].sum())
 
         return {"counts": np.array(counts, dtype=int)}
 
@@ -1093,7 +1092,7 @@ class FluxPointsEstimator:
         return {"sqrt_ts": sqrt_ts, "ts": ts}
 
     def estimate_norm_scan(self):
-        """Estimate likelihood profile for the norm parameter
+        """Estimate likelihood profile for the norm parameter.
 
         Returns
         -------
@@ -1188,8 +1187,65 @@ class FluxPointsDataset(Dataset):
                 " either 'chi2' or 'chi2assym'"
             )
 
+    def __repr__(self):
+        str_ = self.__class__.__name__
+        return str_
+
+    def __str__(self):
+        str_ = "{}: \n".format(self.__class__.__name__)
+        str_ += "\n"
+        if self.model is None:
+            str_ += "\t{:32}:   {} \n".format("Model Name", "No Model")
+        else:
+            str_ += "\t{:32}:   {} \n".format("Total flux points", len(self.data.table))
+            str_ += "\t{:32}:   {} \n".format(
+                "Points used for the fit", self.mask.sum()
+            )
+            str_ += "\t{:32}:   {} \n".format(
+                "Excluded for safe energy range",
+                (~self.mask_safe).sum(),
+            )
+            if self.mask_fit is None:
+                str_ += "\t{:32}:   {} \n".format("Excluded by user", "0")
+            else:
+                str_ += "\t{:32}:   {} \n".format(
+                    "Excluded by user", (~self.mask_fit).sum()
+                )
+            str_ += "\t{:32}:   {}\n".format(
+                "Model Name", self.model.__class__.__name__
+            )
+            str_ += "\t{:32}:   {}\n".format(
+                "N parameters", len(self.parameters.parameters)
+            )
+            str_ += "\t{:32}:   {}\n".format(
+                "N free parameters", len(self.parameters.free_parameters)
+            )
+            str_ += "\tList of parameters\n"
+            for par in self.parameters.parameters:
+                if par.frozen:
+                    if par.name == "amplitude":
+                        str_ += "\t \t {:14} (Frozen):   {:.2e} {} \n".format(
+                            par.name, par.value, par.unit
+                        )
+                    else:
+                        str_ += "\t \t {:14} (Frozen):   {:.2f} {} \n".format(
+                            par.name, par.value, par.unit
+                        )
+                else:
+                    if par.name == "amplitude":
+                        str_ += "\t \t {:23}:   {:.2e} {} \n".format(
+                            par.name, par.value, par.unit
+                        )
+                    else:
+                        str_ += "\t \t {:23}:   {:.2f} {} \n".format(
+                            par.name, par.value, par.unit
+                        )
+            str_ += "\t{:32}:   {}\n".format("Likelihood type", self._likelihood)
+            str_ += "\t{:32}:   {:.2f}\n".format("Likelihood value", self.likelihood())
+        return str_
+
     def data_shape(self):
-        """Shape of the flux points data"""
+        """Shape of the flux points data (tuple)."""
         return self.data.e_ref.shape
 
     @staticmethod
@@ -1198,9 +1254,7 @@ class FluxPointsDataset(Dataset):
 
     @staticmethod
     def _likelihood_chi2_assym(data, model, sigma_n, sigma_p):
-        """
-        Assymetric chi2 statistics for a list of flux points and model.
-        """
+        """Assymetric chi2 statistics for a list of flux points and model."""
         is_p = model > data
         sigma = sigma_n
         sigma[is_p] = sigma_p[is_p]
@@ -1211,7 +1265,7 @@ class FluxPointsDataset(Dataset):
         return self.model(self.data.e_ref)
 
     def likelihood_per_bin(self):
-        """Likelihood per bin given the current model parameters"""
+        """Likelihood per bin given the current model parameters."""
         model = self.flux_pred()
         data = self.data.table["dnde"].quantity
 
@@ -1226,28 +1280,43 @@ class FluxPointsDataset(Dataset):
             # TODO: add likelihood profiles
             pass
 
-    def residuals(self):
-        """Compute flux point residuals
+    def residuals(self, method="diff"):
+        """Compute the flux point residuals ().
+
+        Parameters
+        ----------
+        method: {"diff", "diff/model", "diff/sqrt(model)"}
+            Method used to compute the residuals. Available options are:
+                - `diff` (default): data - model
+                - `diff/model`: (data - model) / model
+                - `diff/sqrt(model)`: (data - model) / sqrt(model)
+                - `norm='sqrt_model'` for: (flux points - model)/sqrt(model)
 
-        Defined as `(data - model) / model`.
 
         Returns
         -------
         residuals : `~numpy.ndarray`
-            Flux point residuals
+            Residuals array.
         """
         fp = self.data
-        data = fp.table[fp.sed_type].quantity
+        data = fp.table[fp.sed_type]
 
         model = self.model(fp.e_ref)
-        residuals = ((data - model) / model).to_value("")
 
+        residuals = data - model
+
+        residuals = self._compute_residuals(data, model, method)
         # Remove residuals for upper_limits
         residuals[fp.is_ul] = np.nan
         return residuals
 
-    def peek(self, **kwargs):
+    def peek(self, norm=None, **kwargs):
         """Plot flux points, best fit model and residuals.
+
+        Parameters
+        ----------
+        norm: `str`
+            normalization used to compute the spectral residuals. Choose between `None`, `model` and `sqrt_model`.
         """
         from matplotlib.gridspec import GridSpec
         import matplotlib.pyplot as plt
@@ -1260,7 +1329,7 @@ class FluxPointsDataset(Dataset):
         ax_spectrum.set_xticks([])
 
         ax_residuals = plt.subplot(gs[5:, :])
-        self.plot_residuals(ax=ax_residuals)
+        self.plot_residuals(ax=ax_residuals, norm=norm)
         return ax_spectrum, ax_residuals
 
     @property
@@ -1274,13 +1343,15 @@ class FluxPointsDataset(Dataset):
     def _e_unit(self):
         return self.data.e_ref.unit
 
-    def plot_residuals(self, ax=None, **kwargs):
+    def plot_residuals(self, ax=None, method="diff", **kwargs):
         """Plot flux point residuals.
 
         Parameters
         ----------
         ax : `~matplotlib.pyplot.Axes`
             Axes object.
+        method : {"diff", "diff/model", "diff/sqrt(model)"}
+            Method used to compute the residuals, see `MapDataset.residuals()`
         **kwargs : dict
             Keyword arguments passed to `~matplotlib.pyplot.errorbar`.
 
@@ -1293,7 +1364,7 @@ class FluxPointsDataset(Dataset):
 
         ax = plt.gca() if ax is None else ax
 
-        residuals = self.residuals()
+        residuals = self.residuals(method=method)
 
         fp = self.data
 
@@ -1303,19 +1374,32 @@ class FluxPointsDataset(Dataset):
 
         model = self.model(fp.e_ref)
         yerr = fp._plot_get_flux_err(fp.sed_type)
-        yerr = (yerr[0] / model).to_value(""), (yerr[1] / model).to_value("")
+
+        if method == "diff":
+            unit = yerr[0].unit
+            yerr = yerr[0].to_value(unit), yerr[1].to_value(unit)
+        elif method == "diff/model":
+            unit = ""
+            yerr = (yerr[0] / model).to_value(""), (yerr[1] / model).to_value(unit)
+        else:
+            raise ValueError("Invalid method, choose between 'diff' and 'diff/model'")
 
         kwargs.setdefault("marker", "+")
         kwargs.setdefault("ls", "None")
-        ax.errorbar(self.data.e_ref.value, residuals, xerr=xerr, yerr=yerr, **kwargs)
+        kwargs.setdefault("color", "black")
+
+        ax.errorbar(
+            self.data.e_ref.value, residuals.value, xerr=xerr, yerr=yerr, **kwargs
+        )
 
         # format axes
         ax.axhline(0, color="black", lw=0.5)
-        ax.set_ylabel("Residuals")
+        ax.set_ylabel("Residuals   {}".format(unit.__str__()))
         ax.set_xlabel("Energy ({})".format(self._e_unit))
-        ax.set_ylim(-1, 1)
         ax.set_xscale("log")
         ax.set_xlim(self._e_range.to_value(self._e_unit))
+        y_max = 2 * np.nanmax(residuals).value
+        ax.set_ylim(-y_max, y_max)
         return ax
 
     def plot_spectrum(self, ax=None, fp_kwargs=None, model_kwargs=None):
