@@ -5,7 +5,7 @@ import numpy as np
 from scipy.optimize import brentq
 import astropy.units as u
 from astropy.table import Table
-from ..utils.energy import EnergyBounds
+from ..utils.energy import energy_logspace
 from ..utils.scripts import make_path
 from ..utils.fitting import Parameter, Parameters, Model
 from ..utils.interpolation import ScaledRegularGridInterpolator
@@ -20,11 +20,15 @@ __all__ = [
     "ExponentialCutoffPowerLaw",
     "ExponentialCutoffPowerLaw3FGL",
     "PLSuperExpCutoff3FGL",
+    "PLSuperExpCutoff4FGL",
     "LogParabola",
     "TableModel",
     "AbsorbedSpectralModel",
     "Absorption",
     "NaimaModel",
+    "SpectralGaussian",
+    "SpectralLogGaussian",
+    "ScaleModel",
 ]
 
 
@@ -38,8 +42,7 @@ class SpectralModel(Model):
     """
 
     def __call__(self, energy):
-        """Call evaluate method of derived classes"""
-        kwargs = dict()
+        kwargs = {}
         for par in self.parameters.parameters:
             quantity = par.quantity
             if quantity.unit.physical_type == "energy":
@@ -209,18 +212,12 @@ class SpectralModel(Model):
         uarray = integrate_spectrum(f, emin.value, emax.value, **kwargs)
         return self._parse_uarray(uarray) * unit
 
-    def to_dict(self):
-        """Convert to dict."""
-        retval = self.parameters.to_dict()
-        retval["name"] = self.__class__.__name__
-        return retval
-
     @classmethod
-    def from_dict(cls, val):
+    def from_dict(cls, data):
         """Create from dict."""
-        val_copy = val.copy()
-        classname = val_copy.pop("name")
-        parameters = Parameters.from_dict(val_copy)
+        data = data.copy()
+        classname = data.pop("type")
+        parameters = Parameters.from_dict(data)
         model = globals()[classname]()
         model.parameters = parameters
         model.parameters.covariance = parameters.covariance
@@ -275,7 +272,7 @@ class SpectralModel(Model):
         ax = plt.gca() if ax is None else ax
 
         emin, emax = energy_range
-        energy = EnergyBounds.equal_log_spacing(emin, emax, n_points, energy_unit)
+        energy = energy_logspace(emin, emax, n_points, energy_unit)
 
         # evaluate model
         flux = self(energy).to(flux_unit)
@@ -345,7 +342,7 @@ class SpectralModel(Model):
         kwargs.setdefault("linewidth", 0)
 
         emin, emax = energy_range
-        energy = EnergyBounds.equal_log_spacing(emin, emax, n_points, energy_unit)
+        energy = energy_logspace(emin, emax, n_points, energy_unit)
 
         flux, flux_err = self.evaluate_error(energy).to(flux_unit)
 
@@ -434,7 +431,7 @@ class SpectralModel(Model):
 
 
 class ConstantModel(SpectralModel):
-    r"""Constant model
+    r"""Constant model.
 
     .. math:: \phi(E) = k
 
@@ -458,9 +455,9 @@ class ConstantModel(SpectralModel):
 
 
 class CompoundSpectralModel(SpectralModel):
-    """Represents the algebraic combination of two
-    `~gammapy.spectrum.models.SpectralModel`
+    """Arithmetic combination of two spectral models.
 
+    Itself again a spectral model.
     """
 
     def __init__(self, model1, model2, operator):
@@ -535,6 +532,42 @@ class PowerLaw(SpectralModel):
         """Evaluate the model (static function)."""
         return amplitude * np.power((energy / reference), -index)
 
+    @staticmethod
+    def evaluate_integral(emin, emax, index, amplitude, reference):
+        """Evaluate the model integral (static function)."""
+        val = -1 * index + 1
+
+        prefactor = amplitude * reference / val
+        upper = np.power((emax / reference), val)
+        lower = np.power((emin / reference), val)
+        integral = prefactor * (upper - lower)
+
+        mask = np.isclose(val, 0)
+
+        if mask.any():
+            integral[mask] = (amplitude * reference * np.log(emax / emin))[mask]
+
+        return integral
+
+    @staticmethod
+    def evaluate_energy_flux(emin, emax, index, amplitude, reference):
+        """Evaluate the energy flux (static function)"""
+        val = -1 * index + 2
+
+        prefactor = amplitude * reference ** 2 / val
+        upper = (emax / reference) ** val
+        lower = (emin / reference) ** val
+        energy_flux = prefactor * (upper - lower)
+
+        mask = np.isclose(val, 0)
+
+        if mask.any():
+            # see https://www.wolframalpha.com/input/?i=a+*+x+*+(x%2Fb)+%5E+(-2)
+            # for reference
+            energy_flux[mask] = amplitude * reference ** 2 * np.log(emax / emin)[mask]
+
+        return energy_flux
+
     def integral(self, emin, emax, **kwargs):
         r"""Integrate power law analytically.
 
@@ -548,24 +581,10 @@ class PowerLaw(SpectralModel):
         emin, emax : `~astropy.units.Quantity`
             Lower and upper bound of integration range
         """
-        # kwargs are passed to this function but not used
-        # this is to get a consistent API with SpectralModel.integral()
-        pars = self.parameters
-
-        if np.isclose(pars["index"].value, 1):
-            e_unit = emin.unit
-            prefactor = pars["amplitude"].quantity * pars["reference"].quantity.to(
-                e_unit
-            )
-            upper = np.log(emax.to_value(e_unit))
-            lower = np.log(emin.to_value(e_unit))
-        else:
-            val = -1 * pars["index"].value + 1
-            prefactor = pars["amplitude"].quantity * pars["reference"].quantity / val
-            upper = np.power((emax / pars["reference"].quantity), val)
-            lower = np.power((emin / pars["reference"].quantity), val)
-
-        return prefactor * (upper - lower)
+        emin = self._convert_energy(emin)
+        emax = self._convert_energy(emax)
+        kwargs = {p.name: p.quantity for p in self.parameters.parameters}
+        return self.evaluate_integral(emin=emin, emax=emax, **kwargs)
 
     def integral_error(self, emin, emax, **kwargs):
         r"""Integrate power law analytically with error propagation.
@@ -614,21 +633,10 @@ class PowerLaw(SpectralModel):
         emin, emax : `~astropy.units.Quantity`
             Lower and upper bound of integration range.
         """
-        pars = self.parameters
-        val = -1 * pars["index"].value + 2
-
-        if np.isclose(val, 0):
-            # see https://www.wolframalpha.com/input/?i=a+*+x+*+(x%2Fb)+%5E+(-2)
-            # for reference
-            temp = pars["amplitude"].quantity * pars["reference"].quantity ** 2
-            return temp * np.log(emax / emin)
-        else:
-            prefactor = (
-                pars["amplitude"].quantity * pars["reference"].quantity ** 2 / val
-            )
-            upper = (emax / pars["reference"].quantity) ** val
-            lower = (emin / pars["reference"].quantity) ** val
-            return prefactor * (upper - lower)
+        emin = self._convert_energy(emin)
+        emax = self._convert_energy(emax)
+        kwargs = {p.name: p.quantity for p in self.parameters.parameters}
+        return self.evaluate_energy_flux(emin=emin, emax=emax, **kwargs)
 
     def energy_flux_error(self, emin, emax, **kwargs):
         r"""Compute energy flux in given energy range analytically with error propagation.
@@ -676,6 +684,22 @@ class PowerLaw(SpectralModel):
         base = value / p["amplitude"].quantity
         return p["reference"].quantity * np.power(base, -1.0 / p["index"].value)
 
+    @property
+    def pivot_energy(self):
+        r"""The decorrelation energy is defined as:
+
+        .. math::
+
+            E_D = E_0 * \exp{cov(\phi_0, \Gamma) / (\phi_0 \Delta \Gamma^2)}
+
+        Formula (1) in https://arxiv.org/pdf/0910.4881.pdf
+        """
+        index_err = self.parameters.error("index")
+        reference = self.reference.quantity
+        amplitude = self.amplitude.quantity
+        cov_index_ampl = self.parameters.covariance[0, 1] * amplitude.unit
+        return reference * np.exp(cov_index_ampl / (amplitude * index_err ** 2))
+
 
 class PowerLaw2(SpectralModel):
     r"""Spectral power-law model with integral as amplitude parameter.
@@ -1012,6 +1036,78 @@ class PLSuperExpCutoff3FGL(SpectralModel):
         return pwl * cutoff
 
 
+class PLSuperExpCutoff4FGL(SpectralModel):
+    r"""Spectral super exponential cutoff power-law model used for 4FGL.
+
+    This model parametrisation is very similar, but slightly different from
+    `PLSuperExpCutoff3FGL` or `ExponentialCutoffPowerLaw3FGL`.
+
+    See Equation (3) in https://arxiv.org/pdf/1902.10045.pdf
+
+    .. math::
+        \phi(E) = \phi_0 \cdot \left(\frac{E}{E_0}\right)^{-\Gamma_1}
+                  \exp \left(
+                      a \left( E_0 ^{\Gamma_2} - E^{\Gamma_2} \right)
+                  \right)
+
+    Parameters
+    ----------
+    index_1 : `~astropy.units.Quantity`
+        :math:`\Gamma_1`
+    index_2 : `~astropy.units.Quantity`
+        :math:`\Gamma_2`
+    amplitude : `~astropy.units.Quantity`
+        :math:`\phi_0`
+    reference : `~astropy.units.Quantity`
+        :math:`E_0`
+    expfactor : `~astropy.units.Quantity`
+        :math: `a`
+
+    Examples
+    --------
+    This is how to plot the default `PLSuperExpCutoff4FGL` model::
+
+        from astropy import units as u
+        from gammapy.spectrum.models import PLSuperExpCutoff4FGL
+
+        model = PLSuperExpCutoff4FGL()
+        model.plot(energy_range=[0.1, 100] * u.TeV)
+        plt.show()
+    """
+
+    __slots__ = ["index_1", "index_2", "amplitude", "reference", "expfactor"]
+
+    def __init__(
+        self,
+        index_1=1.5,
+        index_2=2,
+        amplitude="1e-12 cm-2 s-1 TeV-1",
+        reference="1 TeV",
+        expfactor="1e-2 TeV-2",
+    ):
+        self.index_1 = Parameter("index_1", index_1)
+        self.index_2 = Parameter("index_2", index_2)
+        self.amplitude = Parameter("amplitude", amplitude)
+        self.reference = Parameter("reference", reference, frozen=True)
+        self.expfactor = Parameter("expfactor", expfactor)
+
+        super().__init__(
+            [self.index_1, self.index_2, self.amplitude, self.reference, self.expfactor]
+        )
+
+    @staticmethod
+    def evaluate(energy, amplitude, reference, expfactor, index_1, index_2):
+        """Evaluate the model (static function)."""
+        pwl = amplitude * (energy / reference) ** (-index_1)
+        try:
+            cutoff = np.exp(expfactor * (reference ** index_2 - energy ** index_2))
+        except AttributeError:
+            from uncertainties.unumpy import exp
+
+            cutoff = exp(expfactor * (reference ** index_2 - energy ** index_2))
+        return pwl * cutoff
+
+
 class LogParabola(SpectralModel):
     r"""Spectral log parabola model.
 
@@ -1067,7 +1163,7 @@ class LogParabola(SpectralModel):
 
     @classmethod
     def from_log10(cls, amplitude, reference, alpha, beta):
-        """Construct LogParabola from :math:`log_{10}` parametrization"""
+        """Construct from :math:`log_{10}` parametrization."""
         beta_ = beta / np.log(10)
         return cls(amplitude=amplitude, reference=reference, alpha=alpha, beta=beta_)
 
@@ -1153,7 +1249,7 @@ class TableModel(SpectralModel):
 
     @classmethod
     def read_xspec_model(cls, filename, param, **kwargs):
-        """Read XSPEC table model
+        """Read XSPEC table model.
 
         The input is a table containing absorbed values from a XSPEC model as a
         function of energy.
@@ -1180,24 +1276,20 @@ class TableModel(SpectralModel):
 
         # Check if parameter value is in range
         table_param = Table.read(filename, hdu="PARAMETERS")
-        param_min = table_param["MINIMUM"]
-        param_max = table_param["MAXIMUM"]
-        if param < param_min or param > param_max:
-            err = "Parameter out of range, param={}, param_min={}, param_max={}".format(
-                param, param_min, param_max
+        pmin = table_param["MINIMUM"]
+        pmax = table_param["MAXIMUM"]
+        if param < pmin or param > pmax:
+            raise ValueError(
+                "Out of range: param={}, min={}, max={}".format(param, pmin, pmax)
             )
-            raise ValueError(err)
 
         # Get energy values
         table_energy = Table.read(filename, hdu="ENERGIES")
         energy_lo = table_energy["ENERG_LO"]
         energy_hi = table_energy["ENERG_HI"]
 
-        # Hack while format is not fixed, energy values are in keV
-        energy_bounds = EnergyBounds.from_lower_and_upper_bounds(
-            lower=energy_lo, upper=energy_hi, unit=u.keV
-        )
-        energy = energy_bounds.log_centers
+        # set energy to log-centers
+        energy = np.sqrt(energy_lo * energy_hi)
 
         # Get spectrum values (no interpolation, take closest value for param)
         table_spectra = Table.read(filename, hdu="SPECTRA")
@@ -1209,9 +1301,9 @@ class TableModel(SpectralModel):
 
     @classmethod
     def read_fermi_isotropic_model(cls, filename, **kwargs):
-        """Read Fermi isotropic diffuse model
+        """Read Fermi isotropic diffuse model.
 
-        see `LAT Background models <https://fermi.gsfc.nasa.gov/ssc/data/access/lat/BackgroundModels.html>`_
+        See `LAT Background models <https://fermi.gsfc.nasa.gov/ssc/data/access/lat/BackgroundModels.html>`_
 
         Parameters
         ----------
@@ -1229,6 +1321,20 @@ class TableModel(SpectralModel):
         values = self._evaluate((energy,), clip=True)
         return norm * values
 
+    def to_dict(self, selection="all"):
+        return {
+            "type": self.__class__.__name__,
+            "parameters": self.parameters.to_dict(selection)["parameters"],
+            "energy": {
+                "data": self.energy.data.tolist(),
+                "unit": str(self.energy.unit),
+            },
+            "values": {
+                "data": self.values.data.tolist(),
+                "unit": str(self.values.unit),
+            },
+        }
+
 
 class ScaleModel(SpectralModel):
     """Wrapper to scale another spectral model by a norm factor.
@@ -1378,11 +1484,11 @@ class Absorption:
         References
         ----------
         .. [1] Franceschini et al., "Extragalactic optical-infrared background radiation, its time evolution and the cosmic photon-photon opacity",
-            `Link <http://adsabs.harvard.edu/abs/2008A%26A...487..837F>`__
+            `Link <https://ui.adsabs.harvard.edu/abs/2008A%26A...487..837F>`__
         .. [2] Dominguez et al., " Extragalactic background light inferred from AEGIS galaxy-SED-type fractions"
-            `Link <http://adsabs.harvard.edu/abs/2011MNRAS.410.2556D>`__
+            `Link <https://ui.adsabs.harvard.edu/abs/2011MNRAS.410.2556D>`__
         .. [3] Finke et al., "Modeling the Extragalactic Background Light from Stars and Dust"
-            `Link <http://adsabs.harvard.edu/abs/2010ApJ...712..238F>`__
+            `Link <https://ui.adsabs.harvard.edu/abs/2010ApJ...712..238F>`__
         """
         models = dict()
         models["franceschini"] = "$GAMMAPY_DATA/ebl/ebl_franceschini.fits.gz"
@@ -1457,7 +1563,7 @@ class AbsorbedSpectralModel(SpectralModel):
 
 
 class NaimaModel(SpectralModel):
-    r"""A wrapper for Naima models
+    r"""A wrapper for Naima models.
 
     This class provides an interface with the models defined in the `~naima.models` module.
     The model accepts as a positional argument a `Naima <https://naima.readthedocs.io/en/latest/>`_
@@ -1567,7 +1673,7 @@ class NaimaModel(SpectralModel):
         )
 
     def evaluate(self, energy, **kwargs):
-        """Evaluate the model"""
+        """Evaluate the model."""
         for name, value in kwargs.items():
             setattr(self._particle_distribution, name, value)
 
@@ -1586,3 +1692,162 @@ class NaimaModel(SpectralModel):
 
         unit = 1 / (energy.unit * u.cm ** 2 * u.s)
         return dnde.to(unit)
+
+
+class SpectralGaussian(SpectralModel):
+    r"""Gaussian spectral model.
+
+    .. math::
+
+        \phi(E) = \frac{N_0}{\sigma \sqrt{2\pi}}  \exp{ \frac{\left( E-\bar{E} \right)^2 }{2 \sigma^2} }
+
+
+
+    Parameters
+    ----------
+    norm : `~astropy.units.Quantity`
+        :math:`N_0`
+    mean : `~astropy.units.Quantity`
+        :math:`\bar{E}`
+    sigma : `~astropy.units.Quantity`
+        :math:`\sigma`
+
+
+    Examples
+    --------
+    This is how to plot the default `Gaussian` spectral model:
+
+    .. code:: python
+
+        from astropy import units as u
+        from gammapy.spectrum.models import SpectralGaussian
+
+        gaussian = SpectralGaussian()
+        gaussian.plot(energy_range=[0.1, 100] * u.TeV)
+        plt.show()
+    """
+
+    def __init__(
+        self, norm=1e-12 * u.Unit("cm-2 s-1"), mean=1 * u.TeV, sigma=2 * u.TeV
+    ):
+        self.norm = Parameter("norm", norm)
+        self.mean = Parameter("mean", mean)
+        self.sigma = Parameter("sigma", sigma)
+
+        super().__init__([self.norm, self.mean, self.sigma])
+
+    @staticmethod
+    def evaluate(energy, norm, mean, sigma):
+        return (
+            norm
+            / (sigma * np.sqrt(2 * np.pi))
+            * np.exp((energy - mean) ** 2 / (2 * sigma ** 2))
+        )
+
+    def integral(self, emin, emax, **kwargs):
+        r"""Integrate Gaussian analytically.
+
+        .. math::
+            F(E_{min}, E_{max}) = \frac{N_0}{2} \left[ erf(\frac{E - \bar{E}}{\sqrt{2} \sigma})\right]_{E_{min}}^{E_{max}}
+
+
+        Parameters
+        ----------
+        emin, emax : `~astropy.units.Quantity`
+            Lower and upper bound of integration range
+        """
+        from scipy.special import erf
+
+        # kwargs are passed to this function but not used
+        # this is to get a consistent API with SpectralModel.integral()
+        pars = self.parameters
+        u_min = (
+            (emin - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+        ).to_value("")
+        u_max = (
+            (emax - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+        ).to_value("")
+
+        return pars["norm"].quantity / (2) * (erf(u_max) - erf(u_min))
+
+    def energy_flux(self, emin, emax):
+        r"""Compute energy flux in given energy range analytically.
+
+        .. math::
+            G(E_{min}, E_{max}) =  \frac{N_0 \sigma}{\sqrt{2*\pi}}* \left[ - \exp(\frac{E_{min}-\bar{E}}{\sqrt{2} \sigma})
+            \right]_{E_{min}}^{E_{max}} + \frac{N_0 * \bar{E}}{2} \left[ erf(\frac{E - \bar{E}}{\sqrt{2} \sigma})
+             \right]_{E_{min}}^{E_{max}}
+
+
+        Parameters
+        ----------
+        emin, emax : `~astropy.units.Quantity`
+            Lower and upper bound of integration range.
+        """
+        from scipy.special import erf
+
+        pars = self.parameters
+        u_min = (
+            (emin - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+        ).to_value("")
+        u_max = (
+            (emax - pars["mean"].quantity) / (np.sqrt(2) * pars["sigma"].quantity)
+        ).to_value("")
+        a = pars["norm"].quantity * pars["sigma"].quantity / np.sqrt(2 * np.pi)
+        b = pars["norm"].quantity * pars["mean"].quantity / 2
+        return a * (np.exp(-u_min ** 2) - np.exp(-u_max ** 2)) + b * (
+            erf(u_max) - erf(u_min)
+        )
+
+
+class SpectralLogGaussian(SpectralModel):
+    r"""Gaussian Log spectral model.
+
+    .. math::
+
+        \phi(E) = \frac{N_0}{E \, \sigma \sqrt{2\pi}}
+         \exp{ \frac{\left( \ln(\frac{E}{\bar{E}}) \right)^2 }{2 \sigma^2} }
+
+    This model was used in this CTA study for the electron spectrum: Table 3
+     in https://ui.adsabs.harvard.edu/abs/2013APh....43..171B
+
+
+    Parameters
+    ----------
+    norm : `~astropy.units.Quantity`
+        :math:`N_0`
+    mean : `~astropy.units.Quantity`
+        :math:`\bar{E}`
+    sigma : `float`
+        :math:`\sigma`
+
+
+    Examples
+    --------
+    This is how to plot a Gaussian Log spectral model. Very similar from the `SpectralGaussian` model but the Gaussian
+    is based on the logarithm of the energy
+
+    .. code:: python
+
+        from astropy import units as u
+        from gammapy.spectrum.models import SpectralLogGaussian
+
+        gaussian = SpectralLogGaussian()
+        gaussian.plot(energy_range=[0.1, 100] * u.TeV)
+        plt.show()
+    """
+
+    def __init__(self, norm=1e-12 * u.Unit("cm-2 s-1"), mean=1 * u.TeV, sigma=2):
+        self.norm = Parameter("norm", norm)
+        self.mean = Parameter("mean", mean)
+        self.sigma = Parameter("sigma", sigma)
+
+        super().__init__([self.norm, self.mean, self.sigma])
+
+    @staticmethod
+    def evaluate(energy, norm, mean, sigma):
+        return (
+            norm
+            / (energy * sigma * np.sqrt(2 * np.pi))
+            * np.exp(-(np.log(energy / mean)) ** 2 / (2 * sigma ** 2))
+        )
