@@ -1,19 +1,20 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 from astropy.table import Table, Column
 import astropy.units as u
 from ..stats import excess_matching_significance_on_off
 from .models import PowerLaw
-from .utils import CountsPredictor
+from .utils import SpectrumEvaluator
 
 __all__ = ["SensitivityEstimator"]
 
 
-class SensitivityEstimator(object):
+class SensitivityEstimator:
     """Estimate differential sensitivity.
 
     Uses a 1D spectral analysis and on / off measurement.
 
+    For a usage example see :gp-notebook:`cta_sensitivity`
+
     Parameters
     ----------
     arf : `~gammapy.irf.EffectiveAreaTable`
@@ -35,8 +36,6 @@ class SensitivityEstimator(object):
     bkg_sys : float, optional
         Fraction of Background systematics relative to the number of ON counts
 
-    An example can be found in :gp-notebook:`cta_sensitivity` .
-
     Notes
     -----
     This class allows to determine for each reconstructed energy bin the flux associated to the number of gamma-ray
@@ -75,12 +74,11 @@ class SensitivityEstimator(object):
 
     def run(self):
         """Run the computation."""
-
         # TODO: let the user decide on energy binning
         # then integrate bkg model and gamma over those energy bins.
-        energy = self.rmf.e_reco.log_center()
+        energy = self.rmf.e_reco.center
 
-        bkg_counts = (self.bkg.data.data.to("1/s") * self.livetime).value
+        bkg_counts = (self.bkg.quantity.to("1/s") * self.livetime).value
 
         excess_counts = excess_matching_significance_on_off(
             n_off=bkg_counts / self.alpha, alpha=self.alpha, significance=self.sigma
@@ -93,11 +91,10 @@ class SensitivityEstimator(object):
         )
 
         # TODO: simplify the following computation
-        predictor = CountsPredictor(
+        predictor = SpectrumEvaluator(
             model, aeff=self.arf, edisp=self.rmf, livetime=self.livetime
         )
-        predictor.run()
-        counts = predictor.npred.data.data.value
+        counts = predictor.compute_npred().data
         phi_0 = excess_counts / counts
 
         dnde_model = model(energy=energy)
