@@ -40,7 +40,7 @@ def cash(n_on, mu_on):
     * `Sherpa help page on the Cash statistic
       <http://cxc.harvard.edu/sherpa/ahelp/cash.html>`_
     * `Cash 1979, ApJ 228, 939
-      <http://adsabs.harvard.edu/abs/1979ApJ...228..939C>`_
+      <https://ui.adsabs.harvard.edu/abs/1979ApJ...228..939C>`_
     """
     n_on = np.asanyarray(n_on)
     mu_on = np.asanyarray(mu_on)
@@ -88,7 +88,7 @@ def cstat(n_on, mu_on, n_on_min=N_ON_MIN):
     * `Sherpa help page on the C statistic
       <http://cxc.harvard.edu/sherpa/ahelp/cash.html>`_
     * `Cash 1979, ApJ 228, 939
-      <http://adsabs.harvard.edu/abs/1979ApJ...228..939C>`_
+      <https://ui.adsabs.harvard.edu/abs/1979ApJ...228..939C>`_
     """
     n_on = np.asanyarray(n_on, dtype=np.float64)
     mu_on = np.asanyarray(mu_on, dtype=np.float64)
@@ -182,9 +182,9 @@ def wstat(n_on, n_off, alpha, mu_sig, mu_bkg=None, extra_terms=True):
 
 
 def get_wstat_mu_bkg(n_on, n_off, alpha, mu_sig):
-    """Calculate ``mu_bkg`` for wstat
+    """Background estimate ``mu_bkg`` for WSTAT.
 
-    see :ref:`wstat`.
+    See :ref:`wstat`.
     """
     n_on = np.atleast_1d(np.asanyarray(n_on, dtype=np.float64))
     n_off = np.atleast_1d(np.asanyarray(n_off, dtype=np.float64))
@@ -200,9 +200,9 @@ def get_wstat_mu_bkg(n_on, n_off, alpha, mu_sig):
 
 
 def get_wstat_gof_terms(n_on, n_off):
-    """Calculate goodness of fit terms for wstat
+    """Goodness of fit terms for WSTAT.
 
-    see :ref:`wstat`.
+    See :ref:`wstat`.
     """
     term = np.zeros(len(n_on))
 
