@@ -4,12 +4,11 @@
 * known background level ``mu_bkg``
 * background estimated from ``n_off`
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 import numpy as np
 from scipy.stats import norm, poisson
 from scipy.special import erf
 from scipy.optimize import fsolve
-from .significance import significance_to_probability_normal
+from .normal import significance_to_probability_normal
 
 __all__ = [
     "background",
@@ -58,8 +57,7 @@ def background(n_off, alpha):
 
 
 def background_error(n_off, alpha):
-    r"""Estimate standard error on background
-    in the on region from an off-region observation.
+    r"""Estimate standard error on background in the on region from an off-region observation.
 
     .. math::
           \Delta\mu_{bkg} = \alpha \times \sqrt{n_{off}}
@@ -199,7 +197,7 @@ def significance(n_on, mu_bkg, method="lima", n_on_min=1):
     References
     ----------
     .. [1] Li and Ma, "Analysis methods for results in gamma-ray astronomy",
-       `Link <http://adsabs.harvard.edu/abs/1983ApJ...272..317L>`_
+       `Link <https://ui.adsabs.harvard.edu/abs/1983ApJ...272..317L>`_
 
     See Also
     --------
@@ -284,7 +282,7 @@ def significance_on_off(n_on, n_off, alpha, method="lima"):
     References
     ----------
     .. [1] Li and Ma, "Analysis methods for results in gamma-ray astronomy",
-       `Link <http://adsabs.harvard.edu/abs/1983ApJ...272..317L>`_
+       `Link <https://ui.adsabs.harvard.edu/abs/1983ApJ...272..317L>`_
 
     See Also
     --------
@@ -351,7 +349,7 @@ def _significance_direct(n_on, mu_bkg):
 def _significance_direct_on_off(n_on, n_off, alpha):
     """Compute significance directly via Poisson probability.
 
-    Reference: http://adsabs.harvard.edu/abs/1993NIMPA.328..570A
+    Reference: https://ui.adsabs.harvard.edu/abs/1993NIMPA.328..570A
 
     You can use this method for small n_on < 10.
     In this case the Li & Ma formula isn't correct any more.
@@ -376,7 +374,7 @@ def _significance_direct_on_off(n_on, n_off, alpha):
 def excess_ul_helene(excess, excess_error, significance):
     """Compute excess upper limit using the Helene method.
 
-    Reference: http://adsabs.harvard.edu/abs/1984NIMPA.228..120H
+    Reference: https://ui.adsabs.harvard.edu/abs/1984NIMPA.228..120H
 
     Parameters
     ----------
