@@ -1,5 +1,4 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 import numpy as np
 from numpy.testing import assert_allclose
@@ -25,9 +24,10 @@ def test_acceptance_interval_gauss():
     x_bins = np.linspace(-n_sigma * sigma, n_sigma * sigma, n_step, endpoint=True)
 
     # The test reverses a result from the Feldman and Cousins paper. According
-    # to Table X, for a measured value of 2.6 the 90% confidence interval should
-    # be 1.02 and 4.24. Reversed that means that for mu=1.02, the acceptance
-    # interval should end at 2.6 and for mu=4.24 should start at 2.6.
+    # to Table X, for a measured value of 2.6 the 90% confidence interval
+    # should be 1.02 and 4.24. Reversed, that means that for mu=1.02, the
+    # acceptance interval should end at 2.6 and for mu=4.24 should start at
+    # 2.6.
     (x_min, x_max) = fc_find_acceptance_interval_gauss(1.02, sigma, x_bins, cl)
     assert_allclose(x_max, 2.6, atol=0.1)
 
@@ -52,9 +52,9 @@ def test_acceptance_interval_poisson():
     x_bins = np.arange(0, n_bins_x)
 
     # The test reverses a result from the Feldman and Cousins paper. According
-    # to Table IV, for a measured value of 10 the 90% confidence interval should
-    # be 5.00 and 16.00. Reversed that means that for mu=5.0, the acceptance
-    # interval should end at 10 and for mu=16.00 should start at 10.
+    # to Table IV, for a measured value of 10 the 90% confidence interval
+    # should be 5.00 and 16.00. Reversed that means that for mu=5.0, the
+    # acceptance interval should end at 10 and for mu=16.00 should start at 10.
     (x_min, x_max) = fc_find_acceptance_interval_poisson(5.00, background, x_bins, cl)
     assert_allclose(x_max, 10)
 
@@ -75,7 +75,9 @@ def test_numerical_confidence_interval_pdfs():
     cl = 0.90
 
     x_bins = np.arange(0, n_bins_x)
-    mu_bins = np.linspace(mu_min, mu_max, mu_max / step_width_mu + 1, endpoint=True)
+    mu_bins = np.linspace(
+        mu_min, mu_max, int(mu_max / step_width_mu) + 1, endpoint=True
+    )
 
     matrix = [scipy.stats.poisson(mu + background).pmf(x_bins) for mu in mu_bins]
 
@@ -122,15 +124,18 @@ def test_numerical_confidence_interval_values():
     cl = 0.90
 
     x_bins = np.linspace(-n_sigma * sigma, n_sigma * sigma, n_bins_x, endpoint=True)
-    mu_bins = np.linspace(mu_min, mu_max, mu_max / step_width_mu + 1, endpoint=True)
-
-    distribution_dict = dict(
-        (mu, [scipy.stats.norm.rvs(loc=mu, scale=sigma, size=5000)]) for mu in mu_bins
+    mu_bins = np.linspace(
+        mu_min, mu_max, int(mu_max / step_width_mu) + 1, endpoint=True
     )
 
-    acceptance_intervals = fc_construct_acceptance_intervals(
-        distribution_dict, x_bins, cl
-    )
+    rng = np.random.RandomState(seed=0)
+
+    dist = {
+        mu: scipy.stats.norm.rvs(loc=mu, scale=sigma, size=2500, random_state=rng)
+        for mu in mu_bins
+    }
+
+    acceptance_intervals = fc_construct_acceptance_intervals(dist, x_bins, cl)
 
     lower_limit_num, upper_limit_num, _ = fc_get_limits(
         mu_bins, x_bins, acceptance_intervals
