@@ -1,9 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-"""
-Time-based analysis.
-"""
+"""Time analysis."""
 from .simulate import *
 from .lightcurve import *
-from .exptest import *
+from .lightcurve_estimator import *
+from .events import *
 from .period import *
-from .plot_periodogram import *
