@@ -1,3 +1,4 @@
+# Licensed under a 3-clause BSD style license - see LICENSE.rst
 """Gammapy documentation generator utilities.
 
 This is for the Sphinx docs build of Gammapy itself,
@@ -15,9 +16,9 @@ Here's some good resources with working examples:
 - https://github.com/sphinx-doc/sphinx/blob/master/sphinx/directives/other.py
 - https://github.com/bokeh/bokeh/tree/master/bokeh/sphinxext
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import re
+from pathlib import Path
 from distutils.util import strtobool
 from docutils.parsers.rst.directives.images import Image
 from docutils.parsers.rst.directives import register_directive
@@ -26,7 +27,7 @@ from docutils import nodes
 from sphinx.util import logging
 from nbformat.v4 import new_markdown_cell
 import nbformat
-from ..extern.pathlib import Path
+from .. import version
 
 try:
     gammapy_data_path = Path(os.environ["GAMMAPY_DATA"])
@@ -59,14 +60,13 @@ class DocsImage(Image):
                 "GAMMAPY_DATA not available. "
                 "Missing image: name: {!r} filename: {!r}".format(self.name, filename)
             )
-            self.options["alt"] = self.arguments[1]
+            self.options["alt"] = self.arguments[1] if len(self.arguments) > 1 else ""
 
-        return super(DocsImage, self).run()
+        return super().run()
 
 
 def LinkNotebook(name, rawtext, notebook, lineno, inliner, options={}, content=[]):
     """Link to a notebook"""
-
     # check if file exists in local notebooks folder
     nbfolder = Path("notebooks")
     nbfilename = notebook + ".ipynb"
@@ -113,19 +113,24 @@ def gammapy_sphinx_ext_activate():
     roles.register_local_role("gp-notebook", LinkNotebook)
 
 
-def parse_notebooks(folder, url_docs, git_commit):
+def parse_notebooks(folder, url_docs):
     """
     Modifies raw and html-fixed notebooks so they will not have broken links
     to other files in the documentation. Adds a box to the sphinx formatted
     notebooks with info and links to the *.ipynb and *.py files.
     """
+    if version.release:
+        release_number_docs = release_number_binder = version.version
+    else:
+        release_number_binder = "master"
+        release_number_docs = "dev"
 
     DOWNLOAD_CELL = """
 <div class="alert alert-info">
 
 **This is a fixed-text formatted version of a Jupyter notebook**
 
-- Try online [![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/gammapy/gammapy/{git_commit}?urlpath=lab/tree/{nb_filename})
+- Try online [![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/gammapy/gammapy-webpage/{release_number_binder}?urlpath=lab/tree/{nb_filename})
 - You can contribute with your own notebooks in this
 [GitHub repository](https://github.com/gammapy/gammapy/tree/master/tutorials).
 - **Source files:**
@@ -141,7 +146,9 @@ def parse_notebooks(folder, url_docs, git_commit):
             nb_filename = str(nbpath).replace("notebooks/", "")
             py_filename = nb_filename.replace("ipynb", "py")
             ctx = dict(
-                nb_filename=nb_filename, py_filename=py_filename, git_commit=git_commit
+                nb_filename=nb_filename,
+                py_filename=py_filename,
+                release_number_binder=release_number_binder,
             )
             strcell = DOWNLOAD_CELL.format(**ctx)
             rawnb = nbformat.read(str(nbpath), as_version=nbformat.NO_CONVERT)
@@ -165,33 +172,31 @@ def parse_notebooks(folder, url_docs, git_commit):
         txt = nbpath.read_text(encoding="utf-8")
         if str(folder) == "notebooks":
             repl = r"..\/\1rst\2"
+            txt = re.sub(
+                pattern=url_docs + r"(.*?)html(\)|#)",
+                repl=repl,
+                string=txt,
+                flags=re.M | re.I,
+            )
         else:
-            repl = r"..\/..\/\1html\2"
-        txt = re.sub(
-            pattern=url_docs + r"(.*?)html(\)|#)",
-            repl=repl,
-            string=txt,
-            flags=re.M | re.I,
-        )
+            url_docs_release = url_docs.replace("dev", release_number_docs)
+            txt = txt.replace(url_docs, url_docs_release)
+
         nbpath.write_text(txt, encoding="utf-8")
 
 
 def gammapy_sphinx_notebooks(setup_cfg):
-    """
-    Manages the processes for the building of sphinx formatted notebooks
-    """
-
+    """Manage creation of Sphinx-formatted notebooks."""
     if not strtobool(setup_cfg["build_notebooks"]):
         log.info("Config build_notebooks is False; skipping notebook processing")
         return
 
     url_docs = setup_cfg["url_docs"]
-    git_commit = setup_cfg["git_commit"]
 
     # fix links
     filled_notebooks_folder = Path("notebooks")
     download_notebooks_folder = Path("_static") / "notebooks"
 
     if filled_notebooks_folder.is_dir():
-        parse_notebooks(filled_notebooks_folder, url_docs, git_commit)
-        parse_notebooks(download_notebooks_folder, url_docs, git_commit)
+        parse_notebooks(filled_notebooks_folder, url_docs)
+        parse_notebooks(download_notebooks_folder, url_docs)
