@@ -1,14 +1,26 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
-from __future__ import absolute_import, division, print_function, unicode_literals
 import copy
+from .parameter import Parameters
 
 __all__ = ["Model"]
 
 
-class Model(object):
+class Model:
     """Model base class."""
 
-    # TODO: expose model parameters as attributes
+    __slots__ = ["_parameters"]
+
+    def __init__(self, params=None):
+        self._parameters = Parameters(params)
+
+    @property
+    def parameters(self):
+        """Parameters (`~gammapy.utils.modeling.Parameters`)"""
+        return self._parameters
+
+    @parameters.setter
+    def parameters(self, parameters):
+        self._parameters = parameters
 
     def copy(self):
         """A deep copy."""
@@ -26,3 +38,9 @@ class Model(object):
             covariance = self.parameters.covariance_to_table()
             ss += "\n\t".join(covariance.pformat())
         return ss
+
+    def to_dict(self, selection="all"):
+        return {
+            "type": self.__class__.__name__,
+            "parameters": self.parameters.to_dict(selection)["parameters"],
+        }
